@@ -1,6 +1,6 @@
 /*
- *      Copyright (C) 2005-2013 Team XBMC
- *      http://xbmc.org
+ *      Copyright (C) 2005-2008 Team XBMC
+ *      http://www.xbmc.org
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,41 +13,39 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with XBMC; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
+ *  along with XBMC; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  http://www.gnu.org/copyleft/gpl.html
  *
  */
 
-#include "threads/SystemClock.h"
 #include "PartyModeManager.h"
 #include "PlayListPlayer.h"
-#include "music/MusicDatabase.h"
-#include "music/windows/GUIWindowMusicPlaylist.h"
-#include "video/VideoDatabase.h"
-#include "playlists/SmartPlayList.h"
-#include "profiles/ProfilesManager.h"
-#include "dialogs/GUIDialogProgress.h"
+#include "MusicDatabase.h"
+#include "VideoDatabase.h"
+#include "GUIWindowMusicPlaylist.h"
+#include "SmartPlaylist.h"
+#include "GUIDialogProgress.h"
 #include "GUIUserMessages.h"
-#include "guilib/GUIWindowManager.h"
-#include "dialogs/GUIDialogOK.h"
-#include "playlists/PlayList.h"
+#include "GUIWindowManager.h"
+#include "GUIDialogOK.h"
+#include "PlayList.h"
+#include "Settings.h"
 #include "utils/TimeUtils.h"
-#include "utils/log.h"
-#include "utils/StringUtils.h"
-#include "Application.h"
-#include "interfaces/AnnouncementManager.h"
 
 using namespace std;
 using namespace PLAYLIST;
 
 #define QUEUE_DEPTH       10
 
+CPartyModeManager g_partyModeManager;
+
 CPartyModeManager::CPartyModeManager(void)
 {
   m_bIsVideo = false;
   m_bEnabled = false;
-  m_strCurrentFilterMusic.clear();
-  m_strCurrentFilterVideo.clear();
+  m_strCurrentFilterMusic.Empty();
+  m_strCurrentFilterVideo.Empty();
   ClearState();
 }
 
@@ -60,39 +58,34 @@ bool CPartyModeManager::Enable(PartyModeContext context /*= PARTYMODECONTEXT_MUS
   // Filter using our PartyMode xml file
   CSmartPlaylist playlist;
   CStdString partyModePath;
-  bool playlistLoaded;
 
   m_bIsVideo = context == PARTYMODECONTEXT_VIDEO;
-  if (!strXspPath.empty()) //if a path to a smartplaylist is supplied use it
+  if (!strXspPath.IsEmpty()) //if a path to a smartplaylist is supplied use it
     partyModePath = strXspPath;
   else if (m_bIsVideo)
-    partyModePath = CProfilesManager::Get().GetUserDataItem("PartyMode-Video.xsp");
+    partyModePath = g_settings.GetUserDataItem("PartyMode-Video.xsp");
   else
-    partyModePath = CProfilesManager::Get().GetUserDataItem("PartyMode.xsp");
-
-  playlistLoaded=playlist.Load(partyModePath);
-
-  if ( playlistLoaded )
+    partyModePath = g_settings.GetUserDataItem("PartyMode.xsp");
+  if (playlist.Load(partyModePath))
   {
     m_type = playlist.GetType();
     if (context == PARTYMODECONTEXT_UNKNOWN)
     {
       //get it from the xsp file
-      m_bIsVideo = (m_type.Equals("video") || m_type.Equals("musicvideos") || m_type.Equals("mixed"));
+      m_bIsVideo = (m_type.Equals("video") || m_type.Equals("mixed"));
     }
-
     if (m_type.Equals("mixed"))
       playlist.SetType("songs");
-
+    m_strCurrentFilterMusic = playlist.GetWhereClause();
     if (m_type.Equals("mixed"))
       playlist.SetType("video");
-
+    m_strCurrentFilterVideo = playlist.GetWhereClause();
     playlist.SetType(m_type);
   }
   else
   {
-    m_strCurrentFilterMusic.clear();
-    m_strCurrentFilterVideo.clear();
+    m_strCurrentFilterMusic.Empty();
+    m_strCurrentFilterVideo.Empty();
     m_type = m_bIsVideo ? "musicvideos" : "songs";
   }
 
@@ -106,23 +99,19 @@ bool CPartyModeManager::Enable(PartyModeContext context /*= PARTYMODECONTEXT_MUS
   pDialog->StartModal();
 
   ClearState();
-  unsigned int time = XbmcThreads::SystemClockMillis();
+  unsigned int time = CTimeUtils::GetTimeMS();
   vector< pair<int,int> > songIDs;
   if (m_type.Equals("songs") || m_type.Equals("mixed"))
   {
-    CMusicDatabase db;
-    if (db.Open())
+    CMusicDatabase musicdatabase;
+    if (musicdatabase.Open())
     {
-      set<CStdString> playlists;
-      if ( playlistLoaded )
-        m_strCurrentFilterMusic = playlist.GetWhereClause(db, playlists);
-
       CLog::Log(LOGINFO, "PARTY MODE MANAGER: Registering filter:[%s]", m_strCurrentFilterMusic.c_str());
-      m_iMatchingSongs = (int)db.GetSongIDs(m_strCurrentFilterMusic, songIDs);
+      m_iMatchingSongs = (int)musicdatabase.GetSongIDs(m_strCurrentFilterMusic, songIDs);
       if (m_iMatchingSongs < 1 && m_type.Equals("songs"))
       {
         pDialog->Close();
-        db.Close();
+        musicdatabase.Close();
         OnError(16031, (CStdString)"Party mode found no matching songs. Aborting.");
         return false;
       }
@@ -133,25 +122,20 @@ bool CPartyModeManager::Enable(PartyModeContext context /*= PARTYMODECONTEXT_MUS
       OnError(16033, (CStdString)"Party mode could not open database. Aborting.");
       return false;
     }
-    db.Close();
+    musicdatabase.Close();
   }
-
   if (m_type.Equals("musicvideos") || m_type.Equals("mixed"))
   {
     vector< pair<int,int> > songIDs2;
-    CVideoDatabase db;
-    if (db.Open())
+    CVideoDatabase database;
+    if (database.Open())
     {
-      set<CStdString> playlists;
-      if ( playlistLoaded )
-        m_strCurrentFilterVideo = playlist.GetWhereClause(db, playlists);
-
       CLog::Log(LOGINFO, "PARTY MODE MANAGER: Registering filter:[%s]", m_strCurrentFilterVideo.c_str());
-      m_iMatchingSongs += (int)db.GetMusicVideoIDs(m_strCurrentFilterVideo, songIDs2);
+      m_iMatchingSongs += (int)database.GetMusicVideoIDs(m_strCurrentFilterVideo, songIDs2);
       if (m_iMatchingSongs < 1)
       {
         pDialog->Close();
-        db.Close();
+        database.Close();
         OnError(16031, (CStdString)"Party mode found no matching songs. Aborting.");
         return false;
       }
@@ -162,7 +146,7 @@ bool CPartyModeManager::Enable(PartyModeContext context /*= PARTYMODECONTEXT_MUS
       OnError(16033, (CStdString)"Party mode could not open database. Aborting.");
       return false;
     }
-    db.Close();
+    database.Close();
     songIDs.insert(songIDs.end(),songIDs2.begin(),songIDs2.end());
   }
 
@@ -192,7 +176,7 @@ bool CPartyModeManager::Enable(PartyModeContext context /*= PARTYMODECONTEXT_MUS
     return false;
   }
   CLog::Log(LOGDEBUG, "%s time for song fetch: %u",
-            __FUNCTION__, XbmcThreads::SystemClockMillis() - time);
+            __FUNCTION__, CTimeUtils::GetTimeMS() - time);
 
   // start playing
   g_playlistPlayer.SetCurrentPlaylist(iPlaylist);
@@ -208,7 +192,6 @@ bool CPartyModeManager::Enable(PartyModeContext context /*= PARTYMODECONTEXT_MUS
 
   // done
   m_bEnabled = true;
-  Announce();
   return true;
 }
 
@@ -217,7 +200,6 @@ void CPartyModeManager::Disable()
   if (!IsEnabled())
     return;
   m_bEnabled = false;
-  Announce();
   CLog::Log(LOGINFO,"PARTY MODE MANAGER: Party mode disabled.");
 }
 
@@ -427,19 +409,13 @@ bool CPartyModeManager::AddRandomSongs(int iSongs /* = 0 */)
   return true;
 }
 
-void CPartyModeManager::Add(CFileItemPtr &pItem)
+void CPartyModeManager::Add(const CFileItemPtr &pItem)
 {
   int iPlaylist = m_bIsVideo ? PLAYLIST_VIDEO : PLAYLIST_MUSIC;
-  if (pItem->HasMusicInfoTag())
-  {
-    CMusicDatabase database;
-    database.Open();
-    database.SetPropertiesForFileItem(*pItem);
-  }
 
   CPlayList& playlist = g_playlistPlayer.GetPlaylist(iPlaylist);
   playlist.Add(pItem);
-  CLog::Log(LOGINFO,"PARTY MODE MANAGER: Adding randomly selected song at %i:[%s]", playlist.size() - 1, pItem->GetPath().c_str());
+  CLog::Log(LOGINFO,"PARTY MODE MANAGER: Adding randomly selected song at %i:[%s]", playlist.size() - 1, pItem->m_strPath.c_str());
   m_iMatchingSongsPicked++;
 }
 
@@ -555,17 +531,6 @@ int CPartyModeManager::GetRandomSongs()
   return m_iRandomSongs;
 }
 
-PartyModeContext CPartyModeManager::GetType() const
-{
-  if (!IsEnabled())
-    return PARTYMODECONTEXT_UNKNOWN;
-
-  if (m_bIsVideo)
-    return PARTYMODECONTEXT_VIDEO;
-
-  return PARTYMODECONTEXT_MUSIC;
-}
-
 void CPartyModeManager::ClearState()
 {
   m_iLastUserSong = -1;
@@ -601,12 +566,13 @@ bool CPartyModeManager::AddInitialSongs(vector<pair<int,int> > &songIDs)
 
     vector<pair<int,int> > chosenSongIDs;
     GetRandomSelection(songIDs, iMissingSongs, chosenSongIDs);
-    CStdString sqlWhereMusic = "songview.idSong IN (";
-    CStdString sqlWhereVideo = "idMVideo IN (";
+    CStdString sqlWhereMusic = "where songview.idsong in (";
+    CStdString sqlWhereVideo = "where idmvideo in (";
 
     for (vector< pair<int,int> >::iterator it = chosenSongIDs.begin(); it != chosenSongIDs.end(); it++)
     {
-      CStdString song = StringUtils::Format("%i,", it->second);
+      CStdString song;
+      song.Format("%i,", it->second);
       if (it->first == 1)
         sqlWhereMusic += song;
       if (it->first == 2)
@@ -620,22 +586,21 @@ bool CPartyModeManager::AddInitialSongs(vector<pair<int,int> > &songIDs)
       sqlWhereMusic[sqlWhereMusic.size() - 1] = ')'; // replace the last comma with closing bracket
       CMusicDatabase database;
       database.Open();
-      database.GetSongsByWhere("musicdb://songs/", sqlWhereMusic, items);
+      database.GetSongsByWhere("", sqlWhereMusic, items);
     }
     if (sqlWhereVideo.size() > 19)
     {
       sqlWhereVideo[sqlWhereVideo.size() - 1] = ')'; // replace the last comma with closing bracket
       CVideoDatabase database;
       database.Open();
-      database.GetMusicVideosByWhere("videodb://musicvideos/titles/", sqlWhereVideo, items);
+      database.GetMusicVideosByWhere("videodb://3/2/", sqlWhereVideo, items);
     }
 
     m_history = chosenSongIDs;
     items.Randomize(); //randomizing the initial list or they will be in database order
     for (int i = 0; i < items.Size(); i++)
     {
-      CFileItemPtr item(items[i]);
-      Add(item);
+      Add(items[i]);
       // TODO: Allow "relaxed restrictions" later?
     }
   }
@@ -644,49 +609,53 @@ bool CPartyModeManager::AddInitialSongs(vector<pair<int,int> > &songIDs)
 
 pair<CStdString,CStdString> CPartyModeManager::GetWhereClauseWithHistory() const
 {
+  CStdString historyWhereMusic;
+  CStdString historyWhereVideo;
   // now add this on to the normal where clause
-  std::vector<std::string> historyItemsMusic;
-  std::vector<std::string> historyItemsVideo;
-  for (unsigned int i = 0; i < m_history.size(); i++)
+  if (m_history.size())
   {
-    std::string number = StringUtils::Format("%i", m_history[i].second);
-    if (m_history[i].first == 1)
-      historyItemsMusic.push_back(number);
-    if (m_history[i].first == 2)
-      historyItemsVideo.push_back(number);
-  }
+    if (m_strCurrentFilterMusic.IsEmpty())
+      historyWhereMusic = "where songview.idsong not in (";
+    else
+      historyWhereMusic = m_strCurrentFilterMusic + " and songview.idsong not in (";
+    if (m_strCurrentFilterVideo.IsEmpty())
+      historyWhereVideo = "where idmvideo not in (";
+    else
+      historyWhereVideo = m_strCurrentFilterVideo + " and idmvideo not in (";
 
-  std::string historyWhereMusic;
-  if (!historyItemsMusic.empty())
-  {
-    if (!m_strCurrentFilterMusic.empty())
-      historyWhereMusic = m_strCurrentFilterMusic + " and ";
-    historyWhereMusic += "songview.idSong not in (" + StringUtils::Join(historyItemsMusic, ", ") + ")";
+    for (unsigned int i = 0; i < m_history.size(); i++)
+    {
+      CStdString number;
+      number.Format("%i,", m_history[i].second);
+      if (m_history[i].first == 1)
+        historyWhereMusic += number;
+      if (m_history[i].first == 2)
+        historyWhereVideo += number;
+    }
+    historyWhereMusic.TrimRight(",");
+    historyWhereMusic += ")";
+    historyWhereVideo.TrimRight(",");
+    historyWhereVideo += ")";
   }
-
-  std::string historyWhereVideo;
-  if (!historyItemsVideo.empty())
-  {
-    if (!m_strCurrentFilterVideo.empty())
-      historyWhereVideo = m_strCurrentFilterVideo + " and ";
-    historyWhereVideo += "idMVideo not in (" + StringUtils::Join(historyItemsVideo, ", ") + ")";
-  }
-
-  return make_pair(historyWhereMusic, historyWhereVideo);
+  return make_pair(historyWhereMusic,historyWhereVideo);
 }
 
 void CPartyModeManager::AddToHistory(int type, int songID)
 {
   while (m_history.size() >= m_songsInHistory && m_songsInHistory)
     m_history.erase(m_history.begin());
-  m_history.push_back(make_pair(type,songID));
+  m_history.push_back(make_pair<int,int>(type,songID));
 }
 
 void CPartyModeManager::GetRandomSelection(vector< pair<int,int> >& in, unsigned int number, vector< pair<int,int> >& out)
 {
-  number = min(number, (unsigned int)in.size());
-  random_shuffle(in.begin(), in.end());
-  out.assign(in.begin(), in.begin() + number);
+  // only works if we have < 32768 in the in vector
+  for (unsigned int i = 0; i < number; i++)
+  {
+    int num = rand() % in.size();
+    out.push_back(in[num]);
+    in.erase(in.begin() + num);
+  }
 }
 
 bool CPartyModeManager::IsEnabled(PartyModeContext context /* = PARTYMODECONTEXT_UNKNOWN */) const
@@ -698,15 +667,3 @@ bool CPartyModeManager::IsEnabled(PartyModeContext context /* = PARTYMODECONTEXT
     return !m_bIsVideo;
   return true; // unknown, but we're enabled
 }
-
-void CPartyModeManager::Announce()
-{
-  if (g_application.m_pPlayer->IsPlaying())
-  {
-    CVariant data;
-    
-    data["player"]["playerid"] = g_playlistPlayer.GetCurrentPlaylist();
-    data["property"]["partymode"] = m_bEnabled;
-    ANNOUNCEMENT::CAnnouncementManager::Get().Announce(ANNOUNCEMENT::Player, "xbmc", "OnPropertyChanged", data);
-  }
-}
