@@ -1,6 +1,6 @@
 /*
- *      Copyright (C) 2005-2013 Team XBMC
- *      http://xbmc.org
+ *      Copyright (C) 2005-2008 Team XBMC
+ *      http://www.xbmc.org
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,36 +13,32 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with XBMC; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
+ *  along with XBMC; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  http://www.gnu.org/copyleft/gpl.html
  *
  */
 
-#include "threads/SystemClock.h"
 #include "PlayListPlayer.h"
-#include "playlists/PlayListFactory.h"
+#include "PlayListFactory.h"
 #include "Application.h"
 #include "PartyModeManager.h"
-#include "settings/AdvancedSettings.h"
+#include "AdvancedSettings.h"
 #include "GUIUserMessages.h"
-#include "guilib/GUIWindowManager.h"
-#include "dialogs/GUIDialogOK.h"
-#include "playlists/PlayList.h"
+#include "GUIWindowManager.h"
+#include "GUIDialogOK.h"
+#include "PlayList.h"
 #include "utils/log.h"
 #include "utils/TimeUtils.h"
-#include "utils/StringUtils.h"
-#include "music/tags/MusicInfoTag.h"
-#include "dialogs/GUIDialogKaiToast.h"
-#include "guilib/LocalizeStrings.h"
-#include "interfaces/AnnouncementManager.h"
-#include "guilib/Key.h"
 
 using namespace PLAYLIST;
 
+CPlayListPlayer g_playlistPlayer;
+
 CPlayListPlayer::CPlayListPlayer(void)
 {
-  m_PlaylistMusic = new CPlayList(PLAYLIST_MUSIC);
-  m_PlaylistVideo = new CPlayList(PLAYLIST_VIDEO);
+  m_PlaylistMusic = new CPlayList;
+  m_PlaylistVideo = new CPlayList;
   m_PlaylistEmpty = new CPlayList;
   m_iCurrentSong = -1;
   m_bPlayedFirstFile = false;
@@ -62,22 +58,6 @@ CPlayListPlayer::~CPlayListPlayer(void)
   delete m_PlaylistEmpty;
 }
 
-bool CPlayListPlayer::OnAction(const CAction &action)
-{
-  if (action.GetID() == ACTION_PREV_ITEM && !IsSingleItemNonRepeatPlaylist())
-  {
-    PlayPrevious();
-    return true;
-  }
-  else if (action.GetID() == ACTION_NEXT_ITEM && !IsSingleItemNonRepeatPlaylist())
-  {
-    PlayNext();
-    return true;
-  }
-  else
-    return false;
-}
-
 bool CPlayListPlayer::OnMessage(CGUIMessage &message)
 {
   switch (message.GetMessage())
@@ -85,13 +65,10 @@ bool CPlayListPlayer::OnMessage(CGUIMessage &message)
   case GUI_MSG_NOTIFY_ALL:
     if (message.GetParam1() == GUI_MSG_UPDATE_ITEM && message.GetItem())
     {
-      // update the items in our playlist(s) if necessary
-      for (int i = PLAYLIST_MUSIC; i <= PLAYLIST_VIDEO; i++)
-      {
-        CPlayList &playlist = GetPlaylist(i);
-        CFileItemPtr item = boost::static_pointer_cast<CFileItem>(message.GetItem());
-        playlist.UpdateItem(item.get());
-      }
+      // update our item if necessary
+      CPlayList &playlist = GetPlaylist(m_iCurrentPlayList);
+      CFileItemPtr item = boost::static_pointer_cast<CFileItem>(message.GetItem());
+      playlist.UpdateItem(item.get());
     }
     break;
   case GUI_MSG_PLAYBACK_STOPPED:
@@ -154,9 +131,9 @@ int CPlayListPlayer::GetNextSong()
   if (RepeatedOne(m_iCurrentPlayList))
   {
     // otherwise immediately abort playback
-    if (m_iCurrentSong >= 0 && m_iCurrentSong < playlist.size() && playlist[m_iCurrentSong]->GetProperty("unplayable").asBoolean())
+    if (m_iCurrentSong >= 0 && m_iCurrentSong < playlist.size() && playlist[m_iCurrentSong]->GetPropertyBOOL("unplayable"))
     {
-      CLog::Log(LOGERROR,"Playlist Player: RepeatOne stuck on unplayable item: %i, path [%s]", m_iCurrentSong, playlist[m_iCurrentSong]->GetPath().c_str());
+      CLog::Log(LOGERROR,"Playlist Player: RepeatOne stuck on unplayable item: %i, path [%s]", m_iCurrentSong, playlist[m_iCurrentSong]->m_strPath.c_str());
       CGUIMessage msg(GUI_MSG_PLAYLISTPLAYER_STOPPED, 0, 0, m_iCurrentPlayList, m_iCurrentSong);
       g_windowManager.SendThreadMessage(msg);
       Reset();
@@ -175,96 +152,88 @@ int CPlayListPlayer::GetNextSong()
   return iSong;
 }
 
-bool CPlayListPlayer::PlayNext(int offset, bool bAutoPlay)
+/// \brief Play next entry in current playlist
+void CPlayListPlayer::PlayNext(int offset, bool bAutoPlay)
 {
   int iSong = GetNextSong(offset);
   CPlayList& playlist = GetPlaylist(m_iCurrentPlayList);
 
+  // stop playing
   if ((iSong < 0) || (iSong >= playlist.size()) || (playlist.GetPlayable() <= 0))
   {
-    if(!bAutoPlay)
-      CGUIDialogKaiToast::QueueNotification(CGUIDialogKaiToast::Info, g_localizeStrings.Get(559), g_localizeStrings.Get(34201));
-
     CGUIMessage msg(GUI_MSG_PLAYLISTPLAYER_STOPPED, 0, 0, m_iCurrentPlayList, m_iCurrentSong);
     g_windowManager.SendThreadMessage(msg);
     Reset();
     m_iCurrentPlayList = PLAYLIST_NONE;
-    return false;
+    return;
   }
 
-  return Play(iSong, false);
+  if (bAutoPlay)
+  {
+    CFileItemPtr item = playlist[iSong];
+    if ( item->IsShoutCast() )
+    {
+      return ;
+    }
+  }
+  Play(iSong, bAutoPlay);
+  if (iSong < playlist.size())
+  {
+    if (playlist[iSong]->IsVideo())
+    {
+      if (g_windowManager.GetActiveWindow() == WINDOW_VISUALISATION)
+        g_windowManager.ActivateWindow(WINDOW_FULLSCREEN_VIDEO);
+    }
+    else
+    {
+      if (g_windowManager.GetActiveWindow() == WINDOW_FULLSCREEN_VIDEO)
+        g_windowManager.ActivateWindow(WINDOW_VISUALISATION);
+    }
+  }
+  //g_partyModeManager.OnSongChange();
 }
 
-bool CPlayListPlayer::PlayPrevious()
+/// \brief Play previous entry in current playlist
+void CPlayListPlayer::PlayPrevious()
 {
   if (m_iCurrentPlayList == PLAYLIST_NONE)
-    return false;
+    return ;
 
   CPlayList& playlist = GetPlaylist(m_iCurrentPlayList);
+  if (playlist.size() <= 0) return ;
   int iSong = m_iCurrentSong;
 
   if (!RepeatedOne(m_iCurrentPlayList))
     iSong--;
 
-  if (iSong < 0 && Repeated(m_iCurrentPlayList))
+  if (iSong < 0)
     iSong = playlist.size() - 1;
 
-  if (iSong < 0 || playlist.size() <= 0)
-  {
-    CGUIDialogKaiToast::QueueNotification(CGUIDialogKaiToast::Info, g_localizeStrings.Get(559), g_localizeStrings.Get(34202));
-    return false;
-  }
-
-  return Play(iSong, false, true);
+  Play(iSong, false, true);
 }
 
-bool CPlayListPlayer::IsSingleItemNonRepeatPlaylist() const
-{
-  const CPlayList& playlist = GetPlaylist(m_iCurrentPlayList);
-  return (playlist.size() <= 1 && !RepeatedOne(m_iCurrentPlayList) && !Repeated(m_iCurrentPlayList));
-}
-
-bool CPlayListPlayer::Play()
+void CPlayListPlayer::Play()
 {
   if (m_iCurrentPlayList == PLAYLIST_NONE)
-    return false;
+    return;
 
   CPlayList& playlist = GetPlaylist(m_iCurrentPlayList);
-  if (playlist.size() <= 0) 
-    return false;
+  if (playlist.size() <= 0) return;
 
-  return Play(0);
+  Play(0);
 }
 
-bool CPlayListPlayer::PlaySongId(int songId)
+/// \brief Start playing entry \e iSong in current playlist
+/// \param iSong Song in playlist
+void CPlayListPlayer::Play(int iSong, bool bAutoPlay /* = false */, bool bPlayPrevious /* = false */)
 {
   if (m_iCurrentPlayList == PLAYLIST_NONE)
-    return false;
+    return ;
 
   CPlayList& playlist = GetPlaylist(m_iCurrentPlayList);
-  if (playlist.size() <= 0) 
-    return Play();
-
-  for (int i = 0; i < playlist.size(); i++)
-  {
-    if (playlist[i]->HasMusicInfoTag() && playlist[i]->GetMusicInfoTag()->GetDatabaseId() == songId)
-      return Play(i);
-  }
-  return Play();
-}
-
-bool CPlayListPlayer::Play(int iSong, bool bAutoPlay /* = false */, bool bPlayPrevious /* = false */)
-{
-  if (m_iCurrentPlayList == PLAYLIST_NONE)
-    return false;
-
-  CPlayList& playlist = GetPlaylist(m_iCurrentPlayList);
-  if (playlist.size() <= 0) 
-    return false;
-  if (iSong < 0) 
-    iSong = 0;
-  if (iSong >= playlist.size()) 
-    iSong = playlist.size() - 1;
+  if (playlist.size() <= 0) return ;
+  if (iSong < 0) iSong = 0;
+  if (iSong >= playlist.size()) iSong = playlist.size() - 1;
 
   // check if the item itself is a playlist, and can be expanded
   // only allow a few levels, this could end up in a loop
@@ -275,19 +244,17 @@ bool CPlayListPlayer::Play(int iSong, bool bAutoPlay /* = false */, bool bPlayPr
         break;
   }
 
+  int iPreviousSong = m_iCurrentSong;
   m_iCurrentSong = iSong;
   CFileItemPtr item = playlist[m_iCurrentSong];
   playlist.SetPlayed(true);
 
   m_bPlaybackStarted = false;
 
-  unsigned int playAttempt = XbmcThreads::SystemClockMillis();
-  PlayBackRet ret = g_application.PlayFile(*item, bAutoPlay);
-  if (ret == PLAYBACK_CANCELED)
-    return false;
-  if (ret == PLAYBACK_FAIL)
+  unsigned int playAttempt = CTimeUtils::GetTimeMS();
+  if (!g_application.PlayFile(*item, bAutoPlay))
   {
-    CLog::Log(LOGERROR,"Playlist Player: skipping unplayable item: %i, path [%s]", m_iCurrentSong, item->GetPath().c_str());
+    CLog::Log(LOGERROR,"Playlist Player: skipping unplayable item: %i, path [%s]", m_iCurrentSong, item->m_strPath.c_str());
     playlist.SetUnPlayable(m_iCurrentSong);
 
     // abort on 100 failed CONSECTUTIVE songs
@@ -295,7 +262,7 @@ bool CPlayListPlayer::Play(int iSong, bool bAutoPlay /* = false */, bool bPlayPr
       m_failedSongsStart = playAttempt;
     m_iFailedSongs++;
     if ((m_iFailedSongs >= g_advancedSettings.m_playlistRetries && g_advancedSettings.m_playlistRetries >= 0)
-        || ((XbmcThreads::SystemClockMillis() - m_failedSongsStart  >= (unsigned int)g_advancedSettings.m_playlistTimeout * 1000) && g_advancedSettings.m_playlistTimeout))
+        || ((CTimeUtils::GetTimeMS() - m_failedSongsStart  >= (unsigned int)g_advancedSettings.m_playlistTimeout * 1000) && g_advancedSettings.m_playlistTimeout))
     {
       CLog::Log(LOGDEBUG,"Playlist Player: one or more items failed to play... aborting playback");
 
@@ -309,13 +276,17 @@ bool CPlayListPlayer::Play(int iSong, bool bAutoPlay /* = false */, bool bPlayPr
       m_iCurrentPlayList = PLAYLIST_NONE;
       m_iFailedSongs = 0;
       m_failedSongsStart = 0;
-      return false;
+      return;
     }
 
     // how many playable items are in the playlist?
     if (playlist.GetPlayable() > 0)
     {
-      return bPlayPrevious ? PlayPrevious() : PlayNext();
+      if (bPlayPrevious)
+        PlayPrevious();
+      else
+        PlayNext();
+      return;
     }
     // none? then abort playback
     else
@@ -325,14 +296,10 @@ bool CPlayListPlayer::Play(int iSong, bool bAutoPlay /* = false */, bool bPlayPr
       g_windowManager.SendThreadMessage(msg);
       Reset();
       m_iCurrentPlayList = PLAYLIST_NONE;
-      return false;
+      return;
     }
   }
 
-  // reset the start offset of this item
-  if (item->m_lStartOffset == STARTOFFSET_RESUME)
-    item->m_lStartOffset = 0;
-
   // TODO - move the above failure logic and the below success logic
   //        to callbacks instead so we don't rely on the return value
   //        of PlayFile()
@@ -342,25 +309,54 @@ bool CPlayListPlayer::Play(int iSong, bool bAutoPlay /* = false */, bool bPlayPr
   m_failedSongsStart = 0;
   m_bPlaybackStarted = true;
   m_bPlayedFirstFile = true;
-  return true;
+
+  if (!item->IsShoutCast())
+  {
+    if (iPreviousSong < 0)
+    {
+      CGUIMessage msg(GUI_MSG_PLAYLISTPLAYER_STARTED, 0, 0, m_iCurrentPlayList, m_iCurrentSong, item);
+      g_windowManager.SendThreadMessage( msg );
+    }
+    else
+    {
+      CGUIMessage msg(GUI_MSG_PLAYLISTPLAYER_CHANGED, 0, 0, m_iCurrentPlayList, MAKELONG(m_iCurrentSong, iPreviousSong), item);
+      g_windowManager.SendThreadMessage(msg);
+    }
+  }
 }
 
+/// \brief Change the current song in playlistplayer.
+/// \param iSong Song in playlist
 void CPlayListPlayer::SetCurrentSong(int iSong)
 {
   if (iSong >= -1 && iSong < GetPlaylist(m_iCurrentPlayList).size())
     m_iCurrentSong = iSong;
 }
 
+/// \brief Returns to current song in active playlist.
+/// \return Current song
 int CPlayListPlayer::GetCurrentSong() const
 {
   return m_iCurrentSong;
 }
 
+/// \brief Returns the active playlist.
+/// \return Active playlist \n
+/// Return values can be: \n
+/// - PLAYLIST_NONE \n No playlist active
+/// - PLAYLIST_MUSIC \n Playlist from music playlist window
+/// - PLAYLIST_VIDEO \n Playlist from music playlist window
 int CPlayListPlayer::GetCurrentPlaylist() const
 {
   return m_iCurrentPlayList;
 }
 
+/// \brief Set active playlist.
+/// \param iPlayList Playlist to set active \n
+/// Values can be: \n
+/// - PLAYLIST_NONE \n No playlist active
+/// - PLAYLIST_MUSIC \n Playlist from music playlist window
+/// - PLAYLIST_VIDEO \n Playlist from music playlist window
 void CPlayListPlayer::SetCurrentPlaylist(int iPlaylist)
 {
   if (iPlaylist == m_iCurrentPlayList)
@@ -378,7 +374,7 @@ void CPlayListPlayer::SetCurrentPlaylist(int iPlaylist)
 void CPlayListPlayer::ClearPlaylist(int iPlaylist)
 {
   // clear our applications playlist file
-  g_application.m_strPlayListFile.clear();
+  g_application.m_strPlayListFile.Empty();
 
   CPlayList& playlist = GetPlaylist(iPlaylist);
   playlist.Clear();
@@ -388,6 +384,11 @@ void CPlayListPlayer::ClearPlaylist(int iPlaylist)
   g_windowManager.SendMessage(msg);
 }
 
+/// \brief Get the playlist object specified in \e nPlayList
+/// \param nPlayList Values can be: \n
+/// - PLAYLIST_MUSIC \n Playlist from music playlist window
+/// - PLAYLIST_VIDEO \n Playlist from music playlist window
+/// \return A reference to the CPlayList object.
 CPlayList& CPlayListPlayer::GetPlaylist(int iPlaylist)
 {
   switch ( iPlaylist )
@@ -422,6 +423,8 @@ const CPlayList& CPlayListPlayer::GetPlaylist(int iPlaylist) const
   }
 }
 
+/// \brief Removes any item from all playlists located on a removable share
+/// \return Number of items removed from PLAYLIST_MUSIC and PLAYLIST_VIDEO
 int CPlayListPlayer::RemoveDVDItems()
 {
   int nRemovedM = m_PlaylistMusic->RemoveDVDItems();
@@ -430,6 +433,7 @@ int CPlayListPlayer::RemoveDVDItems()
   return nRemovedM + nRemovedV;
 }
 
+/// \brief Resets the playlistplayer, but the active playlist stays the same.
 void CPlayListPlayer::Reset()
 {
   m_iCurrentSong = -1;
@@ -441,11 +445,14 @@ void CPlayListPlayer::Reset()
   g_windowManager.SendMessage(msg);
 }
 
+/// \brief Whether or not something has been played yet or not from the current playlist.
 bool CPlayListPlayer::HasPlayedFirstFile() const
 {
   return m_bPlayedFirstFile;
 }
 
+/// \brief Returns \e true if iPlaylist is repeated
+/// \param iPlaylist Playlist to be asked
 bool CPlayListPlayer::Repeated(int iPlaylist) const
 {
   if (iPlaylist >= PLAYLIST_MUSIC && iPlaylist <= PLAYLIST_VIDEO)
@@ -453,16 +460,20 @@ bool CPlayListPlayer::Repeated(int iPlaylist) const
   return false;
 }
 
+/// \brief Returns \e true if iPlaylist repeats one song
+/// \param iPlaylist Playlist to be asked
 bool CPlayListPlayer::RepeatedOne(int iPlaylist) const
 {
-  if (iPlaylist == PLAYLIST_MUSIC || iPlaylist == PLAYLIST_VIDEO)
+  if (iPlaylist >= PLAYLIST_MUSIC && iPlaylist <= PLAYLIST_VIDEO)
     return (m_repeatState[iPlaylist] == REPEAT_ONE);
   return false;
 }
 
-void CPlayListPlayer::SetShuffle(int iPlaylist, bool bYesNo, bool bNotify /* = false */)
+/// \brief Shuffle play the current playlist
+/// \param bYesNo To Enable shuffle play, set to \e true
+void CPlayListPlayer::SetShuffle(int iPlaylist, bool bYesNo)
 {
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
+  if (iPlaylist < PLAYLIST_MUSIC || iPlaylist > PLAYLIST_VIDEO)
     return;
 
   // disable shuffle in party mode
@@ -484,12 +495,6 @@ void CPlayListPlayer::SetShuffle(int iPlaylist, bool bYesNo, bool bNotify /* = f
     else
       playlist.UnShuffle();
 
-    if (bNotify)
-    {
-      CStdString shuffleStr = StringUtils::Format("%s: %s", g_localizeStrings.Get(191).c_str(), g_localizeStrings.Get(bYesNo ? 593 : 591).c_str()); // Shuffle: All/Off
-      CGUIDialogKaiToast::QueueNotification(CGUIDialogKaiToast::Info, g_localizeStrings.Get(559),  shuffleStr);
-    }
-
     // find the previous order value and fix the current song marker
     if (iOrder >= 0)
     {
@@ -500,8 +505,6 @@ void CPlayListPlayer::SetShuffle(int iPlaylist, bool bYesNo, bool bNotify /* = f
       // so dont do anything
     }
   }
-  
-  AnnouncePropertyChanged(iPlaylist, "shuffled", IsShuffled(iPlaylist));
 }
 
 bool CPlayListPlayer::IsShuffled(int iPlaylist) const
@@ -510,55 +513,28 @@ bool CPlayListPlayer::IsShuffled(int iPlaylist) const
   if (g_partyModeManager.IsEnabled() && iPlaylist == PLAYLIST_MUSIC)
     return false;
 
-  if (iPlaylist == PLAYLIST_MUSIC || iPlaylist == PLAYLIST_VIDEO)
+  if (iPlaylist >= PLAYLIST_MUSIC && iPlaylist <= PLAYLIST_VIDEO)
+  {
     return GetPlaylist(iPlaylist).IsShuffled();
-
+  }
   return false;
 }
 
-void CPlayListPlayer::SetRepeat(int iPlaylist, REPEAT_STATE state, bool bNotify /* = false */)
+void CPlayListPlayer::SetRepeat(int iPlaylist, REPEAT_STATE state)
 {
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
+  if (iPlaylist < PLAYLIST_MUSIC || iPlaylist > PLAYLIST_VIDEO)
     return;
 
   // disable repeat in party mode
   if (g_partyModeManager.IsEnabled() && iPlaylist == PLAYLIST_MUSIC)
     state = REPEAT_NONE;
 
-  // notify the user if there was a change in the repeat state
-  if (m_repeatState[iPlaylist] != state && bNotify)
-  {
-    int iLocalizedString;
-    if (state == REPEAT_NONE)
-      iLocalizedString = 595; // Repeat: Off
-    else if (state == REPEAT_ONE)
-      iLocalizedString = 596; // Repeat: One
-    else
-      iLocalizedString = 597; // Repeat: All
-    CGUIDialogKaiToast::QueueNotification(CGUIDialogKaiToast::Info, g_localizeStrings.Get(559), g_localizeStrings.Get(iLocalizedString));
-  }
-
   m_repeatState[iPlaylist] = state;
-
-  CVariant data;
-  switch (state)
-  {
-  case REPEAT_ONE:
-    data = "one";
-    break;
-  case REPEAT_ALL:
-    data = "all";
-    break;
-  default:
-    data = "off";
-    break;
-  }
-  AnnouncePropertyChanged(iPlaylist, "repeat", data);
 }
 
 REPEAT_STATE CPlayListPlayer::GetRepeat(int iPlaylist) const
 {
-  if (iPlaylist == PLAYLIST_MUSIC || iPlaylist == PLAYLIST_VIDEO)
+  if (iPlaylist >= PLAYLIST_MUSIC && iPlaylist <= PLAYLIST_VIDEO)
     return m_repeatState[iPlaylist];
   return REPEAT_NONE;
 }
@@ -576,8 +552,8 @@ void CPlayListPlayer::ReShuffle(int iPlaylist, int iPosition)
   else if (iPlaylist == m_iCurrentPlayList)
   {
     if (
-      (g_application.m_pPlayer->IsPlayingAudio() && iPlaylist == PLAYLIST_MUSIC) ||
-      (g_application.m_pPlayer->IsPlayingVideo() && iPlaylist == PLAYLIST_VIDEO)
+      (g_application.IsPlayingAudio() && iPlaylist == PLAYLIST_MUSIC) ||
+      (g_application.IsPlayingVideo() && iPlaylist == PLAYLIST_VIDEO)
       )
     {
       g_playlistPlayer.GetPlaylist(iPlaylist).Shuffle(m_iCurrentSong + 2);
@@ -593,7 +569,7 @@ void CPlayListPlayer::ReShuffle(int iPlaylist, int iPosition)
 
 void CPlayListPlayer::Add(int iPlaylist, CPlayList& playlist)
 {
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
+  if (iPlaylist < PLAYLIST_MUSIC || iPlaylist > PLAYLIST_VIDEO)
     return;
   CPlayList& list = GetPlaylist(iPlaylist);
   int iSize = list.size();
@@ -604,7 +580,7 @@ void CPlayListPlayer::Add(int iPlaylist, CPlayList& playlist)
 
 void CPlayListPlayer::Add(int iPlaylist, const CFileItemPtr &pItem)
 {
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
+  if (iPlaylist < PLAYLIST_MUSIC || iPlaylist > PLAYLIST_VIDEO)
     return;
   CPlayList& list = GetPlaylist(iPlaylist);
   int iSize = list.size();
@@ -615,7 +591,7 @@ void CPlayListPlayer::Add(int iPlaylist, const CFileItemPtr &pItem)
 
 void CPlayListPlayer::Add(int iPlaylist, CFileItemList& items)
 {
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
+  if (iPlaylist < PLAYLIST_MUSIC || iPlaylist > PLAYLIST_VIDEO)
     return;
   CPlayList& list = GetPlaylist(iPlaylist);
   int iSize = list.size();
@@ -624,97 +600,20 @@ void CPlayListPlayer::Add(int iPlaylist, CFileItemList& items)
     ReShuffle(iPlaylist, iSize);
 }
 
-void CPlayListPlayer::Insert(int iPlaylist, CPlayList& playlist, int iIndex)
-{
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
-    return;
-  CPlayList& list = GetPlaylist(iPlaylist);
-  int iSize = list.size();
-  list.Insert(playlist, iIndex);
-  if (list.IsShuffled())
-    ReShuffle(iPlaylist, iSize);
-  else if (m_iCurrentPlayList == iPlaylist && m_iCurrentSong >= iIndex)
-    m_iCurrentSong++;
-}
-
-void CPlayListPlayer::Insert(int iPlaylist, const CFileItemPtr &pItem, int iIndex)
-{
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
-    return;
-  CPlayList& list = GetPlaylist(iPlaylist);
-  int iSize = list.size();
-  list.Insert(pItem, iIndex);
-  if (list.IsShuffled())
-    ReShuffle(iPlaylist, iSize);
-  else if (m_iCurrentPlayList == iPlaylist && m_iCurrentSong >= iIndex)
-    m_iCurrentSong++;
-}
-
-void CPlayListPlayer::Insert(int iPlaylist, CFileItemList& items, int iIndex)
-{
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
-    return;
-  CPlayList& list = GetPlaylist(iPlaylist);
-  int iSize = list.size();
-  list.Insert(items, iIndex);
-  if (list.IsShuffled())
-    ReShuffle(iPlaylist, iSize);
-  else if (m_iCurrentPlayList == iPlaylist && m_iCurrentSong >= iIndex)
-    m_iCurrentSong++;
-}
-
-void CPlayListPlayer::Remove(int iPlaylist, int iPosition)
-{
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
-    return;
-  CPlayList& list = GetPlaylist(iPlaylist);
-  list.Remove(iPosition);
-  if (m_iCurrentPlayList == iPlaylist && m_iCurrentSong >= iPosition)
-    m_iCurrentSong--;
-
-  // its likely that the playlist changed
-  CGUIMessage msg(GUI_MSG_PLAYLIST_CHANGED, 0, 0);
-  g_windowManager.SendMessage(msg);
-}
-
 void CPlayListPlayer::Clear()
 {
   if (m_PlaylistMusic)
-    m_PlaylistMusic->Clear();
-  if (m_PlaylistVideo)
-    m_PlaylistVideo->Clear();
-  if (m_PlaylistEmpty)
-    m_PlaylistEmpty->Clear();
-}
-
-void CPlayListPlayer::Swap(int iPlaylist, int indexItem1, int indexItem2)
-{
-  if (iPlaylist != PLAYLIST_MUSIC && iPlaylist != PLAYLIST_VIDEO)
-    return;
-
-  CPlayList& list = GetPlaylist(iPlaylist);
-  if (list.Swap(indexItem1, indexItem2) && iPlaylist == m_iCurrentPlayList)
   {
-    if (m_iCurrentSong == indexItem1)
-      m_iCurrentSong = indexItem2;
-    else if (m_iCurrentSong == indexItem2)
-      m_iCurrentSong = indexItem1;
+    m_PlaylistMusic->Clear();
+  }
+  if (m_PlaylistVideo)
+  {
+    m_PlaylistVideo->Clear();
+  }
+  if (m_PlaylistEmpty)
+  {
+    m_PlaylistEmpty->Clear();
   }
-
-  // its likely that the playlist changed
-  CGUIMessage msg(GUI_MSG_PLAYLIST_CHANGED, 0, 0);
-  g_windowManager.SendMessage(msg);
 }
 
-void CPlayListPlayer::AnnouncePropertyChanged(int iPlaylist, const std::string &strProperty, const CVariant &value)
-{
-  if (strProperty.empty() || value.isNull() ||
-     (iPlaylist == PLAYLIST_VIDEO && !g_application.m_pPlayer->IsPlayingVideo()) ||
-     (iPlaylist == PLAYLIST_MUSIC && !g_application.m_pPlayer->IsPlayingAudio()))
-    return;
 
-  CVariant data;
-  data["player"]["playerid"] = iPlaylist;
-  data["property"][strProperty] = value;
-  ANNOUNCEMENT::CAnnouncementManager::Get().Announce(ANNOUNCEMENT::Player, "xbmc", "OnPropertyChanged", data);
-}
