@@ -1,6 +1,6 @@
 /*
- *      Copyright (C) 2005-2013 Team XBMC
- *      http://xbmc.org
+ *      Copyright (C) 2005-2008 Team XBMC
+ *      http://www.xbmc.org
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,8 +13,9 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with XBMC; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
+ *  along with XBMC; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  http://www.gnu.org/copyleft/gpl.html
  *
  */
 
@@ -22,11 +23,10 @@
 #include "Win32DllLoader.h"
 #include "DllLoader.h"
 #include "DllLoaderContainer.h"
-#include "utils/StdString.h"
+#include "StdString.h"
 #include "Util.h"
 #include "utils/log.h"
-#include "filesystem/SpecialProtocol.h"
-#include "utils/CharsetConverter.h"
+#include "FileSystem/SpecialProtocol.h"
 
 #include "dll_tracker_library.h"
 #include "dll_tracker_file.h"
@@ -40,16 +40,15 @@ extern "C" FARPROC WINAPI dllWin32GetProcAddress(HMODULE hModule, LPCSTR functio
 Export win32_exports[] =
 {
   // kernel32
-  { "FindFirstFileA",                               -1, (void*)dllFindFirstFileA,                            NULL },
-  { "FindNextFileA",                                -1, (void*)dllFindNextFileA,                             NULL },
+  { "FindFirstFileA",                               -1, (void*)dllFindFirstFileA,                               NULL },
   { "GetFileAttributesA",                           -1, (void*)dllGetFileAttributesA,                        NULL },
   { "LoadLibraryA",                                 -1, (void*)dllLoadLibraryA,                              (void*)track_LoadLibraryA },
   { "FreeLibrary",                                  -1, (void*)dllFreeLibrary,                               (void*)track_FreeLibrary },
-  { "GetProcAddress",                               -1, (void*)dllWin32GetProcAddress,                       NULL },
+  { "GetProcAddress",                               -1, (void*)dllWin32GetProcAddress,                            NULL },
   { "SetEvent",                                     -1, (void*)SetEvent,                                     NULL },
 //  { "GetModuleHandleA",                             -1, (void*)dllGetModuleHandleA,                          NULL },
   { "CreateFileA",                                  -1, (void*)dllCreateFileA,                               NULL },
-  { "LoadLibraryExA",                               -1, (void*)dllLoadLibraryExA,                            (void*)track_LoadLibraryExA },
+  { "LoadLibraryExA",                               -1, (void*)dllLoadLibraryExA,                            (void*)track_LoadLibraryExA }, 
   { "GetModuleFileNameA",                           -1, (void*)dllGetModuleFileNameA,                        NULL },
 // potential vfs stuff
 //  { "CreateDirectoryA",                             -1, (void*)dllCreateDirectoryA,                          NULL },
@@ -57,8 +56,7 @@ Export win32_exports[] =
 //  { "LockFileEx",                                   -1, (void*)dllLockFileEx,                                NULL },
 //  { "UnlockFile",                                   -1, (void*)dllUnlockFile,                                NULL },
 //  { "CreateFileW",                                  -1, (void*)CreateFileW,                                  NULL },
-  { "GetFullPathNameW",                             -1, (void*)dllGetFullPathNameW,                            NULL },
-  { "GetFullPathNameA",                             -1, (void*)dllGetFullPathNameA,                            NULL },
+//  { "GetFullPathNameW",                             -1, (void*)GetFullPathNameW,                             NULL },
 //  { "GetTempPathW",                                 -1, (void*)GetTempPathW,                                 NULL },
 //  { "GetFileAttributesW",                           -1, (void*)GetFileAttributesW,                           NULL },
 //  { "DeleteFileW",                                  -1, (void*)DeleteFileW,                                  NULL },
@@ -78,8 +76,6 @@ Export win32_exports[] =
   { "_fstat",                     -1, (void*)dll_fstat,                     NULL },
   { "_mkdir",                     -1, (void*)dll_mkdir,                     NULL },
   { "_stat",                      -1, (void*)dll_stat,                      NULL },
-  { "_fstat32",                   -1, (void*)dll_fstat,                     NULL },
-  { "_stat32",                    -1, (void*)dll_stat,                      NULL },
   { "_findclose",                 -1, (void*)dll_findclose,                 NULL },
   { "_findfirst",                 -1, (void*)dll_findfirst,                 NULL },
   { "_findnext",                  -1, (void*)dll_findnext,                  NULL },
@@ -102,17 +98,13 @@ Export win32_exports[] =
   { "fgetpos",                    -1, (void*)dll_fgetpos,                   NULL },
   { "fsetpos",                    -1, (void*)dll_fsetpos,                   NULL },
   { "_stati64",                   -1, (void*)dll_stati64,                   NULL },
-  { "_stat64",                    -1, (void*)dll_stat64,                    NULL },
-  { "_stat64i32",                 -1, (void*)dll_stat64i32,                 NULL },
   { "_fstati64",                  -1, (void*)dll_fstati64,                  NULL },
-  { "_fstat64",                   -1, (void*)dll_fstat64,                   NULL },
-  { "_fstat64i32",                -1, (void*)dll_fstat64i32,                NULL },
   { "_telli64",                   -1, (void*)dll_telli64,                   NULL },
   { "_tell",                      -1, (void*)dll_tell,                      NULL },
   { "_fileno",                    -1, (void*)dll_fileno,                    NULL },
   { "ferror",                     -1, (void*)dll_ferror,                    NULL },
   { "freopen",                    -1, (void*)dll_freopen,                   (void*)track_freopen},
-  { "fscanf",                     -1, (void*)dll_fscanf,                    NULL },
+  { "fscanf",                     -1, (void*)fscanf,                        NULL },
   { "ungetc",                     -1, (void*)dll_ungetc,                    NULL },
   { "_fdopen",                    -1, (void*)dll_fdopen,                    NULL },
   { "clearerr",                   -1, (void*)dll_clearerr,                  NULL },
@@ -129,16 +121,49 @@ Export win32_exports[] =
 
   // libdvdnav + python need this (due to us using dll_putenv() to put stuff only?)
   { "getenv",                     -1, (void*)dll_getenv,                    NULL },
-  { "_environ",                   -1, (void*)&dll__environ,                 NULL },
-  { "_open_osfhandle",            -1, (void*)dll_open_osfhandle,            NULL },
 
   { NULL,                          -1, NULL,                                NULL }
 };
 
+// stuff for python
+extern "C"
+{
+  char* xbp_getcwd(char *buf, int size);
+  int xbp_chdir(const char *dirname);
+  int xbp_access(const char *path, int mode);
+  int xbp_unlink(const char *filename);
+  int xbp_chmod(const char *filename, int pmode);
+  int xbp_rmdir(const char *dirname);
+  int xbp_utime(const char *filename, struct utimbuf *times);
+  int xbp_rename(const char *oldname, const char *newname);
+  int xbp_mkdir(const char *dirname);
+  int xbp_open(const char *filename, int oflag, int pmode);
+};
+
+Export win32_python_exports[] =
+{
+  // these just correct for path separators and call the base
+  { "access",                               -1, (void*)xbp_access,                               NULL },
+  { "unlink",                               -1, (void*)xbp_unlink,                               NULL },
+  { "chmod",                               -1, (void*)xbp_chmod,                               NULL },
+  { "rmdir",                               -1, (void*)xbp_rmdir,                               NULL },
+  { "utime",                               -1, (void*)xbp_utime,                               NULL },
+  { "rename",                               -1, (void*)xbp_rename,                               NULL },
+  { "mkdir",                               -1, (void*)xbp_mkdir,                               NULL },
+  { "open",                               -1, (void*)xbp_open,                               NULL },
+//  { "opendir",                               -1, (void*)xbp_opendir,                               NULL }, _LINUX only
+
+  // special workaround just for python
+  { "_chdir",                               -1, (void*)xbp_chdir,                               NULL },
+  { "_getcwd",                              -1, (void*)xbp_getcwd,                               NULL },
+  { "_putenv",                              -1, (void*)dll_putenv,                              NULL },
+  { "__p__environ",               -1, (void*)dll___p__environ,              NULL },
+  { NULL,                          -1, NULL,                                NULL }
+};
+
 Win32DllLoader::Win32DllLoader(const char *dll) : LibraryLoader(dll)
 {
   m_dllHandle = NULL;
-  bIsSystemDll = false;
   DllLoaderContainer::RegisterDll(this);
 }
 
@@ -155,42 +180,36 @@ bool Win32DllLoader::Load()
     return true;
 
   CStdString strFileName = GetFileName();
+  CLog::Log(LOGDEBUG, "%s(%s)\n", __FUNCTION__, strFileName.c_str());
+  //int flags = RTLD_LAZY;
+  //if (m_bGlobal) flags |= RTLD_GLOBAL;
+  //m_soHandle = dlopen(strFileName.c_str(), flags);
 
-  CStdStringW strDllW;
-  g_charsetConverter.utf8ToW(CSpecialProtocol::TranslatePath(strFileName), strDllW, false, false, false);
-  m_dllHandle = LoadLibraryExW(strDllW.c_str(), NULL, LOAD_WITH_ALTERED_SEARCH_PATH);
+  // make sure we set working directory
+  CStdString path;
+  CUtil::GetParentPath(strFileName, path);
+  char currentPath[MAX_PATH];
+  GetCurrentDirectory(MAX_PATH, currentPath);
+  SetCurrentDirectory(_P(path).c_str());
+  m_dllHandle = LoadLibrary(_P(strFileName).c_str());
+  SetCurrentDirectory(currentPath);
   if (!m_dllHandle)
   {
-    DWORD dw = GetLastError(); 
-    wchar_t* lpMsgBuf = NULL;
-    DWORD strLen = FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, dw, MAKELANGID(LANG_ENGLISH, SUBLANG_ENGLISH_US), (LPWSTR)&lpMsgBuf, 0, NULL);
-    if (strLen == 0)
-      strLen = FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, dw, MAKELANGID(LANG_NEUTRAL, SUBLANG_NEUTRAL), (LPWSTR)&lpMsgBuf, 0, NULL);
-
-    if (strLen != 0)
-    {
-      std::string strMessage;
-      g_charsetConverter.wToUTF8(std::wstring(lpMsgBuf, strLen), strMessage);
-      CLog::Log(LOGERROR, "%s: Failed to load \"%s\" with error %lu: \"%s\"", __FUNCTION__, CSpecialProtocol::TranslatePath(strFileName).c_str(), dw, strMessage.c_str());
-    }
-    else
-      CLog::Log(LOGERROR, "%s: Failed to load \"%s\" with error %lu", __FUNCTION__, CSpecialProtocol::TranslatePath(strFileName).c_str(), dw);
-    
-    LocalFree(lpMsgBuf);
+    CLog::Log(LOGERROR, "%s: Unable to load %s (%d)", __FUNCTION__, strFileName.c_str(), GetLastError());
     return false;
   }
 
   // handle functions that the dll imports
   if (NeedsHooking(strFileName.c_str()))
     OverrideImports(strFileName);
-  else
-    bIsSystemDll = true;
 
   return true;
 }
 
 void Win32DllLoader::Unload()
 {
+  CLog::Log(LOGDEBUG, "%s %s\n", __FUNCTION__, GetName());
+
   // restore our imports
   RestoreImports();
 
@@ -203,12 +222,11 @@ void Win32DllLoader::Unload()
   m_dllHandle = NULL;
 }
 
-int Win32DllLoader::ResolveExport(const char* symbol, void** f, bool logging)
+int Win32DllLoader::ResolveExport(const char* symbol, void** f)
 {
   if (!m_dllHandle && !Load())
   {
-    if (logging)
-      CLog::Log(LOGWARNING, "%s - Unable to resolve: %s %s, reason: DLL not loaded", __FUNCTION__, GetName(), symbol);
+    CLog::Log(LOGWARNING, "%s - Unable to resolve: %s %s, reason: DLL not loaded", __FUNCTION__, GetName(), symbol);
     return 0;
   }
 
@@ -216,8 +234,7 @@ int Win32DllLoader::ResolveExport(const char* symbol, void** f, bool logging)
 
   if (!s)
   {
-    if (logging)
-      CLog::Log(LOGWARNING, "%s - Unable to resolve: %s %s", __FUNCTION__, GetName(), symbol);
+    CLog::Log(LOGWARNING, "%s - Unable to resolve: %s %s", __FUNCTION__, GetName(), symbol);
     return 0;
   }
 
@@ -227,7 +244,7 @@ int Win32DllLoader::ResolveExport(const char* symbol, void** f, bool logging)
 
 bool Win32DllLoader::IsSystemDll()
 {
-  return bIsSystemDll;
+  return false;
 }
 
 HMODULE Win32DllLoader::GetHModule()
@@ -242,9 +259,7 @@ bool Win32DllLoader::HasSymbols()
 
 void Win32DllLoader::OverrideImports(const CStdString &dll)
 {
-  CStdStringW strdllW;
-  g_charsetConverter.utf8ToW(CSpecialProtocol::TranslatePath(dll), strdllW, false);
-  BYTE* image_base = (BYTE*)GetModuleHandleW(strdllW.c_str());
+  BYTE* image_base = (BYTE*)GetModuleHandle(_P(dll).c_str());
 
   if (!image_base)
   {
@@ -264,7 +279,7 @@ void Win32DllLoader::OverrideImports(const CStdString &dll)
     return;
   }
 
-  // loop over all imported dlls
+  // loop over all imported dlls 
   for (int i = 0; imp_desc[i].Characteristics != 0; i++)
   {
     char *dllName = (char*)(image_base + imp_desc[i].Name);
@@ -275,7 +290,7 @@ void Win32DllLoader::OverrideImports(const CStdString &dll)
       // this will do a loadlibrary on it, which should effectively make sure that it's hooked
       // Note that the library has obviously already been loaded by the OS (as it's implicitly linked)
       // so all this will do is insert our hook and make sure our DllLoaderContainer knows about it
-      HMODULE hModule = dllLoadLibraryA(dllName);
+      HMODULE hModule = dllLoadLibraryA(dllName); 
       if (hModule)
         m_referencedDlls.push_back(hModule);
     }
@@ -337,25 +352,15 @@ bool Win32DllLoader::NeedsHooking(const char *dllName)
         return false;
     }
   }
-  CStdStringW strdllNameW;
-  g_charsetConverter.utf8ToW(CSpecialProtocol::TranslatePath(dllName), strdllNameW, false);
-  HMODULE hModule = GetModuleHandleW(strdllNameW.c_str());
-  if (hModule == NULL)
-    return false;
+  HMODULE hModule = GetModuleHandle(_P(dllName).c_str());
+  char filepath[MAX_PATH];
+  GetModuleFileName(hModule, filepath, MAX_PATH);
+  CStdString dllPath = filepath;
 
-  wchar_t filepathW[MAX_PATH];
-  GetModuleFileNameW(hModule, filepathW, MAX_PATH);
-  CStdString dllPath;
-  g_charsetConverter.wToUTF8(filepathW, dllPath);
-
-  // compare this filepath with some special directories
-  CStdString xbmcPath = CSpecialProtocol::TranslatePath("special://xbmc");
-  CStdString homePath = CSpecialProtocol::TranslatePath("special://home");
-  CStdString tempPath = CSpecialProtocol::TranslatePath("special://temp");
-  return ((strncmp(xbmcPath.c_str(), dllPath.c_str(), xbmcPath.size()) == 0) ||
-    (strncmp(homePath.c_str(), dllPath.c_str(), homePath.size()) == 0) ||
-    (strncmp(tempPath.c_str(), dllPath.c_str(), tempPath.size()) == 0));
-}
+  // compare this filepath with our home directory
+  CStdString homePath = _P("special://xbmc");
+  CStdString tempPath = _P("special://temp");
+  return ((strncmp(homePath.c_str(), filepath, homePath.GetLength()) == 0) || (strncmp(tempPath.c_str(), filepath, tempPath.GetLength()) == 0));}
 
 void Win32DllLoader::RestoreImports()
 {
@@ -402,6 +407,12 @@ bool FunctionNeedsWrapping(Export *exports, const char *functionName, void **fix
 
 bool Win32DllLoader::ResolveImport(const char *dllName, const char *functionName, void **fixup)
 {
+  char *dll = GetName();
+  if (strstr(dll, "python24.dll") || strstr(dll, ".pyd"))
+  { // special case for python
+    if (FunctionNeedsWrapping(win32_python_exports, functionName, fixup))
+      return true;
+  }
   return FunctionNeedsWrapping(win32_exports, functionName, fixup);
 }
 
