@@ -1,6 +1,6 @@
 /*
- *      Copyright (C) 2005-2013 Team XBMC
- *      http://xbmc.org
+ *      Copyright (C) 2005-2008 Team XBMC
+ *      http://www.xbmc.org
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,43 +13,41 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with XBMC; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
+ *  along with XBMC; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  http://www.gnu.org/copyleft/gpl.html
  *
  */
 
-#include "threads/SystemClock.h"
 #include "system.h"
 #include "signal.h"
 #include "limits.h"
-#include "threads/SingleLock.h"
+#include "SingleLock.h"
+#include "AudioContext.h"
 #include "ExternalPlayer.h"
-#include "windowing/WindowingFactory.h"
-#include "dialogs/GUIDialogOK.h"
-#include "guilib/GUIWindowManager.h"
+#include "WindowingFactory.h"
+#include "GUIDialogOK.h"
+#include "GUIFontManager.h"
+#include "GUITextLayout.h"
+#include "GUIWindowManager.h"
 #include "Application.h"
-#include "filesystem/MusicDatabaseFile.h"
+#include "FileSystem/FileMusicDatabase.h"
+#include "Settings.h"
 #include "FileItem.h"
-#include "utils/RegExp.h"
-#include "utils/StringUtils.h"
-#include "utils/URIUtils.h"
+#include "RegExp.h"
+#include "StringUtils.h"
 #include "URL.h"
-#include "utils/XMLUtils.h"
+#include "XMLUtils.h"
 #include "utils/TimeUtils.h"
 #include "utils/log.h"
-#include "cores/AudioEngine/AEFactory.h"
-#if defined(TARGET_WINDOWS)
-  #include "utils/CharsetConverter.h"
+#if defined(_WIN32)
   #include "Windows.h"
   #ifdef HAS_IRSERVERSUITE
-    #include "input/windows/IRServerSuite.h"
+    #include "common/IRServerSuite/IRServerSuite.h"
   #endif
 #endif
 #if defined(HAS_LIRC)
-  #include "input/linux/LIRC.h"
-#endif
-#if defined(TARGET_ANDROID)
-  #include "android/activity/XBMCApp.h"
+  #include "common/LIRC.h"
 #endif
 
 // If the process ends in less than this time (ms), we assume it's a launcher
@@ -62,13 +60,13 @@
 
 using namespace XFILE;
 
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
 extern HWND g_hWnd;
 #endif
 
 CExternalPlayer::CExternalPlayer(IPlayerCallback& callback)
     : IPlayer(callback),
-      CThread("ExternalPlayer")
+      CThread()
 {
   m_bAbortRequest = false;
   m_bIsPlaying = false;
@@ -86,12 +84,8 @@ CExternalPlayer::CExternalPlayer(IPlayerCallback& callback)
   m_playOneStackItem = false;
 
   m_dialog = NULL;
-  m_hwndXbmc = NULL;
-  m_xPos = 0;
-  m_yPos = 0;
 
-
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
   memset(&m_processInfo, 0, sizeof(m_processInfo));
 #endif
 }
@@ -106,7 +100,7 @@ bool CExternalPlayer::OpenFile(const CFileItem& file, const CPlayerOptions &opti
   try
   {
     m_bIsPlaying = true;
-    m_launchFilename = file.GetPath();
+    m_launchFilename = file.m_strPath;
     CLog::Log(LOGNOTICE, "%s: %s", __FUNCTION__, m_launchFilename.c_str());
     Create();
 
@@ -120,13 +114,13 @@ bool CExternalPlayer::OpenFile(const CFileItem& file, const CPlayerOptions &opti
   }
 }
 
-bool CExternalPlayer::CloseFile(bool reopen)
+bool CExternalPlayer::CloseFile()
 {
   m_bAbortRequest = true;
 
   if (m_dialog && m_dialog->IsActive()) m_dialog->Close();
 
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
   if (m_bIsPlaying && m_processInfo.hProcess)
   {
     TerminateProcess(m_processInfo.hProcess, 1);
@@ -143,6 +137,8 @@ bool CExternalPlayer::IsPlaying() const
 
 void CExternalPlayer::Process()
 {
+  SetName("CExternalPlayer");
+
   CStdString mainFile = m_launchFilename;
   CStdString archiveContent = "";
 
@@ -151,40 +147,30 @@ void CExternalPlayer::Process()
     // Unwind archive names
     CURL url(m_launchFilename);
     CStdString protocol = url.GetProtocol();
-    if (protocol == "zip" || protocol == "rar"/* || protocol == "iso9660" ??*/ || protocol == "udf")
+    if (protocol == "zip" || protocol == "rar"/* || protocol == "iso9660" ??*/)
     {
       mainFile = url.GetHostName();
       archiveContent = url.GetFileName();
     }
     if (protocol == "musicdb")
-      mainFile = CMusicDatabaseFile::TranslateUrl(url);
-    if (protocol == "bluray")
-    {
-      CURL base(url.GetHostName());
-      if(base.GetProtocol() == "udf")
-      {
-        mainFile = base.GetHostName(); /* image file */
-        archiveContent = base.GetFileName();
-      }
-      else
-        mainFile = URIUtils::AddFileToFolder(base.Get(), url.GetFileName());
-    }
+      mainFile = CFileMusicDatabase::TranslateUrl(url);
   }
 
-  if (m_filenameReplacers.size() > 0)
+  if (m_filenameReplacers.size() > 0) 
   {
     for (unsigned int i = 0; i < m_filenameReplacers.size(); i++)
     {
-      std::vector<std::string> vecSplit = StringUtils::Split(m_filenameReplacers[i], " , ");
+      std::vector<CStdString> vecSplit;
+      StringUtils::SplitString(m_filenameReplacers[i], " , ", vecSplit);
 
       // something is wrong, go to next substitution
       if (vecSplit.size() != 4)
         continue;
 
       CStdString strMatch = vecSplit[0];
-      StringUtils::Replace(strMatch, ",,",",");
-      bool bCaseless = vecSplit[3].find('i') != std::string::npos;
-      CRegExp regExp(bCaseless, CRegExp::autoUtf8);
+      strMatch.Replace(",,",",");
+      bool bCaseless = vecSplit[3].Find('i') > -1;
+      CRegExp regExp(bCaseless);
 
       if (!regExp.RegComp(strMatch.c_str()))
       { // invalid regexp - complain in logs
@@ -192,10 +178,10 @@ void CExternalPlayer::Process()
         continue;
       }
 
-      if (regExp.RegFind(mainFile) > -1)
+      if (regExp.RegFind(mainFile) > -1) 
       {
         CStdString strPat = vecSplit[1];
-        StringUtils::Replace(strPat, ",,",",");
+        strPat.Replace(",,",",");
 
         if (!regExp.RegComp(strPat.c_str()))
         { // invalid regexp - complain in logs
@@ -204,14 +190,14 @@ void CExternalPlayer::Process()
         }
 
         CStdString strRep = vecSplit[2];
-        StringUtils::Replace(strRep, ",,",",");
-        bool bGlobal = vecSplit[3].find('g') != std::string::npos;
-        bool bStop = vecSplit[3].find('s') != std::string::npos;
+        strRep.Replace(",,",",");
+        bool bGlobal = vecSplit[3].Find('g') > -1;
+        bool bStop = vecSplit[3].Find('s') > -1;
         int iStart = 0;
         while ((iStart = regExp.RegFind(mainFile, iStart)) > -1)
         {
           int iLength = regExp.GetFindLen();
-          mainFile = mainFile.substr(0, iStart) + regExp.GetReplaceString(strRep) + mainFile.substr(iStart + iLength);
+          mainFile = mainFile.Left(iStart) + regExp.GetReplaceString(strRep.c_str()) + mainFile.Mid(iStart+iLength);
           if (!bGlobal)
             break;
         }
@@ -230,9 +216,9 @@ void CExternalPlayer::Process()
   // make sure we surround the arguments with quotes where necessary
   CStdString strFName;
   CStdString strFArgs;
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
   // W32 batch-file handline
-  if (StringUtils::EndsWith(m_filename, ".bat") || StringUtils::EndsWith(m_filename, ".cmd"))
+  if (m_filename.Right(4) == ".bat")
   {
     // MSDN says you just need to do this, but cmd's handing of spaces and
     // quotes is soo broken it seems to work much better if you just omit
@@ -249,10 +235,10 @@ void CExternalPlayer::Process()
   strFArgs.append("\" ");
   strFArgs.append(m_args);
 
-  int nReplaced = StringUtils::Replace(strFArgs, "{0}", mainFile);
+  int nReplaced = strFArgs.Replace("{0}", mainFile);
 
   if (!nReplaced)
-    nReplaced = StringUtils::Replace(strFArgs, "{1}", mainFile) + StringUtils::Replace(strFArgs, "{2}", archiveContent);
+    nReplaced = strFArgs.Replace("{1}", mainFile) + strFArgs.Replace("{2}", archiveContent);
 
   if (!nReplaced)
   {
@@ -261,7 +247,14 @@ void CExternalPlayer::Process()
     strFArgs.append("\"");
   }
 
-#if defined(TARGET_WINDOWS)
+  int iActiveDevice = g_audioContext.GetActiveDevice();
+  if (iActiveDevice != CAudioContext::NONE)
+  {
+    CLog::Log(LOGNOTICE, "%s: Releasing audio device %d", __FUNCTION__, iActiveDevice);
+    g_audioContext.SetActiveDevice(CAudioContext::NONE);
+  }
+
+#if defined(_WIN32)
   if (m_warpcursor)
   {
     GetCursorPos(&m_ptCursorpos);
@@ -294,7 +287,7 @@ void CExternalPlayer::Process()
     CLog::Log(LOGNOTICE, "%s: Hiding XBMC window", __FUNCTION__);
     g_Windowing.Hide();
   }
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
   else if (currentStyle & WS_EX_TOPMOST)
   {
     CLog::Log(LOGNOTICE, "%s: Lowering XBMC window", __FUNCTION__);
@@ -305,33 +298,14 @@ void CExternalPlayer::Process()
   LockSetForegroundWindow(LSFW_UNLOCK);
 #endif
 
-  m_playbackStartTime = XbmcThreads::SystemClockMillis();
-
-  /* Suspend AE temporarily so exclusive or hog-mode sinks */
-  /* don't block external player's access to audio device  */
-  CAEFactory::Suspend();
-  // wait for AE has completed suspended
-  XbmcThreads::EndTime timer(2000);
-  while (!timer.IsTimePast() && !CAEFactory::IsSuspended())
-  {
-    Sleep(50);
-  }
-  if (timer.IsTimePast())
-  {
-    CLog::Log(LOGERROR,"%s: AudioEngine did not suspend before launching external player", __FUNCTION__);
-  }
-
-  m_callback.OnPlayBackStarted();
-
+  m_playbackStartTime = CTimeUtils::GetTimeMS();
   BOOL ret = TRUE;
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
   ret = ExecuteAppW32(strFName.c_str(),strFArgs.c_str());
-#elif defined(TARGET_ANDROID)
-  ret = ExecuteAppAndroid(m_filename.c_str(), mainFile.c_str());
-#elif defined(TARGET_POSIX) || defined(TARGET_DARWIN_OSX)
+#elif defined(_LINUX)
   ret = ExecuteAppLinux(strFArgs.c_str());
 #endif
-  int64_t elapsedMillis = XbmcThreads::SystemClockMillis() - m_playbackStartTime;
+  int64_t elapsedMillis = CTimeUtils::GetTimeMS() - m_playbackStartTime;
 
   if (ret && (m_islauncher || elapsedMillis < LAUNCHER_PROCESS_TIME))
   {
@@ -356,14 +330,13 @@ void CExternalPlayer::Process()
   m_bIsPlaying = false;
   CLog::Log(LOGNOTICE, "%s: Stop", __FUNCTION__);
 
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
   g_Windowing.Restore();
 
   if (currentStyle & WS_EX_TOPMOST)
   {
     CLog::Log(LOGNOTICE, "%s: Showing XBMC window TOPMOST", __FUNCTION__);
     SetWindowPos(g_hWnd,HWND_TOPMOST,0,0,0,0,SWP_NOMOVE|SWP_NOSIZE|SWP_SHOWWINDOW);
-    SetForegroundWindow(g_hWnd);
   }
   else
 #endif
@@ -372,7 +345,7 @@ void CExternalPlayer::Process()
     g_Windowing.Show();
   }
 
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
   if (m_warpcursor)
   {
     m_xPos = 0;
@@ -387,23 +360,23 @@ void CExternalPlayer::Process()
   }
 #endif
 
-  /* Resume AE processing of XBMC native audio */
-  if (!CAEFactory::Resume())
-  {
-    CLog::Log(LOGFATAL, "%s: Failed to restart AudioEngine after return from external player",__FUNCTION__);
-  }
-
   // We don't want to come back to an active screensaver
   g_application.ResetScreenSaver();
   g_application.WakeUpScreenSaverAndDPMS();
 
+  if (iActiveDevice != CAudioContext::NONE)
+  {
+    CLog::Log(LOGNOTICE, "%s: Reclaiming audio device %d", __FUNCTION__, iActiveDevice);
+    g_audioContext.SetActiveDevice(iActiveDevice);
+  }
+
   if (!ret || (m_playOneStackItem && g_application.CurrentFileItem().IsStack()))
     m_callback.OnPlayBackStopped();
   else
     m_callback.OnPlayBackEnded();
 }
 
-#if defined(TARGET_WINDOWS)
+#if defined(_WIN32)
 BOOL CExternalPlayer::ExecuteAppW32(const char* strPath, const char* strSwitches)
 {
   CLog::Log(LOGNOTICE, "%s: %s %s", __FUNCTION__, strPath, strSwitches);
@@ -420,13 +393,13 @@ BOOL CExternalPlayer::ExecuteAppW32(const char* strPath, const char* strSwitches
 
   if (m_bAbortRequest) return false;
 
-  BOOL ret = CreateProcessW(WstrPath.empty() ? NULL : WstrPath.c_str(),
-                            (LPWSTR) WstrSwitches.c_str(), NULL, NULL, FALSE, NULL,
+  BOOL ret = CreateProcessW(WstrPath.IsEmpty() ? NULL : WstrPath.c_str(),
+                            (LPWSTR) WstrSwitches.c_str(), NULL, NULL, FALSE, NULL, 
                             NULL, NULL, &si, &m_processInfo);
 
   if (ret == FALSE)
   {
-    DWORD lastError = GetLastError();
+    DWORD lastError = GetLastError(); 
     CLog::Log(LOGNOTICE, "%s - Failure: %d", __FUNCTION__, lastError);
   }
   else
@@ -460,7 +433,7 @@ BOOL CExternalPlayer::ExecuteAppW32(const char* strPath, const char* strSwitches
 }
 #endif
 
-#if !defined(TARGET_ANDROID) && (defined(TARGET_POSIX) || defined(TARGET_DARWIN_OSX))
+#if defined(_LINUX)
 BOOL CExternalPlayer::ExecuteAppLinux(const char* strSwitches)
 {
   CLog::Log(LOGNOTICE, "%s: %s", __FUNCTION__, strSwitches);
@@ -486,22 +459,6 @@ BOOL CExternalPlayer::ExecuteAppLinux(const char* strSwitches)
 }
 #endif
 
-#if defined(TARGET_ANDROID)
-BOOL CExternalPlayer::ExecuteAppAndroid(const char* strSwitches,const char* strPath)
-{
-  CLog::Log(LOGNOTICE, "%s: %s", __FUNCTION__, strSwitches);
-
-  int ret = CXBMCApp::StartActivity(strSwitches, "android.intent.action.VIEW", "video/*", strPath);
-
-  if (ret != 0)
-  {
-    CLog::Log(LOGNOTICE, "%s: Failure: %d", __FUNCTION__, ret);
-  }
-
-  return ret == 0;
-}
-#endif
-
 void CExternalPlayer::Pause()
 {
 }
@@ -534,7 +491,7 @@ bool CExternalPlayer::CanSeek()
   return false;
 }
 
-void CExternalPlayer::Seek(bool bPlus, bool bLargeStep, bool bChapterOverride)
+void CExternalPlayer::Seek(bool bPlus, bool bLargeStep)
 {
 }
 
@@ -563,8 +520,8 @@ void CExternalPlayer::SeekPercentage(float iPercent)
 
 float CExternalPlayer::GetPercentage()
 {
-  int64_t iTime = GetTime();
-  int64_t iTotalTime = GetTotalTime();
+  __int64 iTime = GetTime();
+  __int64 iTotalTime = GetTotalTime() * 1000;
 
   if (iTotalTime != 0)
   {
@@ -593,13 +550,13 @@ float CExternalPlayer::GetSubTitleDelay()
   return 0.0;
 }
 
-void CExternalPlayer::SeekTime(int64_t iTime)
+void CExternalPlayer::SeekTime(__int64 iTime)
 {
 }
 
-int64_t CExternalPlayer::GetTime() // in millis
+__int64 CExternalPlayer::GetTime() // in millis
 {
-  if ((XbmcThreads::SystemClockMillis() - m_playbackStartTime) / 1000 > m_playCountMinTime)
+  if ((CTimeUtils::GetTimeMS() - m_playbackStartTime) / 1000 > m_playCountMinTime)
   {
     m_time = m_totalTime * 1000;
   }
@@ -607,9 +564,9 @@ int64_t CExternalPlayer::GetTime() // in millis
   return m_time;
 }
 
-int64_t CExternalPlayer::GetTotalTime() // in milliseconds
+int CExternalPlayer::GetTotalTime() // in seconds
 {
-  return (int64_t)m_totalTime * 1000;
+  return m_totalTime;
 }
 
 void CExternalPlayer::ToFFRW(int iSpeed)
@@ -633,7 +590,7 @@ bool CExternalPlayer::SetPlayerState(CStdString state)
 
 bool CExternalPlayer::Initialize(TiXmlElement* pConfig)
 {
-  XMLUtils::GetString(pConfig, "filename", m_filename);
+  XMLUtils::GetString(pConfig, "filename", m_filename); 
   if (m_filename.length() > 0)
   {
     CLog::Log(LOGNOTICE, "ExternalPlayer Filename: %s", m_filename.c_str());
@@ -652,9 +609,9 @@ bool CExternalPlayer::Initialize(TiXmlElement* pConfig)
   XMLUtils::GetBoolean(pConfig, "hidexbmc", m_hidexbmc);
   if (!XMLUtils::GetBoolean(pConfig, "hideconsole", m_hideconsole))
   {
-#ifdef TARGET_WINDOWS
+#ifdef _WIN32
     // Default depends on whether player is a batch file
-    m_hideconsole = StringUtils::EndsWith(m_filename, ".bat");
+    m_hideconsole = m_filename.Right(4) == ".bat";
 #endif
   }
 
@@ -663,7 +620,7 @@ bool CExternalPlayer::Initialize(TiXmlElement* pConfig)
     m_warpcursor = WARP_BOTTOM_RIGHT;
 
   CStdString warpCursor;
-  if (XMLUtils::GetString(pConfig, "warpcursor", warpCursor) && !warpCursor.empty())
+  if (XMLUtils::GetString(pConfig, "warpcursor", warpCursor))
   {
     if (warpCursor == "bottomright") m_warpcursor = WARP_BOTTOM_RIGHT;
     else if (warpCursor == "bottomleft") m_warpcursor = WARP_BOTTOM_LEFT;
@@ -679,13 +636,13 @@ bool CExternalPlayer::Initialize(TiXmlElement* pConfig)
 
   XMLUtils::GetInt(pConfig, "playcountminimumtime", m_playCountMinTime, 1, INT_MAX);
 
-  CLog::Log(LOGNOTICE, "ExternalPlayer Tweaks: hideconsole (%s), hidexbmc (%s), islauncher (%s), warpcursor (%s)",
+  CLog::Log(LOGNOTICE, "ExternalPlayer Tweaks: hideconsole (%s), hidexbmc (%s), islauncher (%s), warpcursor (%s)", 
           m_hideconsole ? "true" : "false",
           m_hidexbmc ? "true" : "false",
           m_islauncher ? "true" : "false",
           warpCursor.c_str());
 
-#ifdef TARGET_WINDOWS
+#ifdef _WIN32
   m_filenameReplacers.push_back("^smb:// , / , \\\\ , g");
   m_filenameReplacers.push_back("^smb:\\\\\\\\ , smb:(\\\\\\\\[^\\\\]*\\\\) , \\1 , ");
 #endif
@@ -701,7 +658,7 @@ bool CExternalPlayer::Initialize(TiXmlElement* pConfig)
 }
 
 void CExternalPlayer::GetCustomRegexpReplacers(TiXmlElement *pRootElement,
-                                               std::vector<std::string>& settings)
+                                               CStdStringArray& settings)
 {
   int iAction = 0; // overwrite
   // for backward compatibility
@@ -739,15 +696,15 @@ void CExternalPlayer::GetCustomRegexpReplacers(TiXmlElement *pRootElement,
       XMLUtils::GetString(pReplacer,"pat",strPat);
       XMLUtils::GetString(pReplacer,"rep",strRep);
 
-      if (!strPat.empty() && !strRep.empty())
+      if (!strPat.IsEmpty() && !strRep.IsEmpty())
       {
         CLog::Log(LOGDEBUG,"  Registering replacer:");
         CLog::Log(LOGDEBUG,"    Match:[%s] Pattern:[%s] Replacement:[%s]", strMatch.c_str(), strPat.c_str(), strRep.c_str());
         CLog::Log(LOGDEBUG,"    Global:[%s] Stop:[%s]", bGlobal?"true":"false", bStop?"true":"false");
         // keep literal commas since we use comma as a seperator
-        StringUtils::Replace(strMatch, ",",",,");
-        StringUtils::Replace(strPat, ",",",,");
-        StringUtils::Replace(strRep, ",",",,");
+        strMatch.Replace(",",",,");
+        strPat.Replace(",",",,");
+        strRep.Replace(",",",,");
 
         CStdString strReplacer = strMatch + " , " + strPat + " , " + strRep + " , " + (bGlobal ? "g" : "") + (bStop ? "s" : "");
         if (iAction == 2)
@@ -758,7 +715,7 @@ void CExternalPlayer::GetCustomRegexpReplacers(TiXmlElement *pRootElement,
       else
       {
         // error message about missing tag
-        if (strPat.empty())
+        if (strPat.IsEmpty())
           CLog::Log(LOGERROR,"  Missing <Pat> tag");
         else
           CLog::Log(LOGERROR,"  Missing <Rep> tag");
