@@ -1,6 +1,6 @@
 /*
- *      Copyright (C) 2005-2013 Team XBMC
- *      http://xbmc.org
+ *      Copyright (C) 2005-2008 Team XBMC
+ *      http://www.xbmc.org
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,24 +13,23 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with XBMC; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
+ *  along with XBMC; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  http://www.gnu.org/copyleft/gpl.html
  *
  */
 
 #include "DVDInputStreamNavigator.h"
-#include "utils/LangCodeExpander.h"
-#include "../DVDDemuxSPU.h"
+#include "Util.h"
+#include "LangCodeExpander.h"
+#include "DVDDemuxSPU.h"
 #include "DVDStateSerializer.h"
-#include "settings/Settings.h"
+#include "GUISettings.h"
 #include "LangInfo.h"
 #include "utils/log.h"
-#include "guilib/Geometry.h"
-#include "utils/URIUtils.h"
-#include "utils/StringUtils.h"
-#include "guilib/LocalizeStrings.h"
-#if defined(TARGET_DARWIN)
-#include "osx/CocoaInterface.h"
+#include "Geometry.h"
+#ifdef __APPLE__
+#include "CocoaInterface.h"
 #endif
 
 #define HOLDMODE_NONE 0
@@ -52,10 +51,6 @@ CDVDInputStreamNavigator::CDVDInputStreamNavigator(IDVDPlayer* player) : CDVDInp
   m_iTitle = m_iTitleCount = 0;
   m_iPart = m_iPartCount = 0;
   m_iTime = m_iTotalTime = 0;
-  m_bEOF = false;
-  m_lastevent = DVDNAV_NOP;
-
-  memset(m_lastblock, 0, sizeof(m_lastblock));
 }
 
 CDVDInputStreamNavigator::~CDVDInputStreamNavigator()
@@ -65,9 +60,11 @@ CDVDInputStreamNavigator::~CDVDInputStreamNavigator()
 
 bool CDVDInputStreamNavigator::Open(const char* strFile, const std::string& content)
 {
-  if (!CDVDInputStream::Open(strFile, "video/x-dvd-mpeg"))
+  char* strDVDFile;
+  m_icurrentGroupId = 0;
+  if (!CDVDInputStream::Open(strFile, "video/x-dvd-mpeg")) 
     return false;
-
+  
   // load libdvdnav.dll
   if (!m_dll.Load())
     return false;
@@ -75,34 +72,35 @@ bool CDVDInputStreamNavigator::Open(const char* strFile, const std::string& cont
   // load the dvd language codes
   // g_LangCodeExpander.LoadStandardCodes();
 
-  // libdvdcss fails if the file path contains VIDEO_TS.IFO or VIDEO_TS/VIDEO_TS.IFO
-  // libdvdnav is still able to play without, so strip them.
-
-  CStdString path = strFile;
-  if(URIUtils::GetFileName(path) == "VIDEO_TS.IFO")
-    path = URIUtils::GetParentPath(path);
-  URIUtils::RemoveSlashAtEnd(path);
-  if(URIUtils::GetFileName(path) == "VIDEO_TS")
-    path = URIUtils::GetParentPath(path);
-  URIUtils::RemoveSlashAtEnd(path);
-
-#if defined(TARGET_DARWIN_OSX)
+  // since libdvdnav automaticly play's the dvd if the directory contains VIDEO_TS.IFO
+  // we strip it here.
+  strDVDFile = strdup(strFile);
+#ifndef _LINUX
+  if (strnicmp(strDVDFile + strlen(strDVDFile) - 12, "VIDEO_TS.IFO", 12) == 0)
+#else
+  if (strncasecmp(strDVDFile + strlen(strDVDFile) - 12, "VIDEO_TS.IFO", 12) == 0)
+#endif
+  {
+    strDVDFile[strlen(strDVDFile) - 13] = '\0';
+  }
+#if defined(__APPLE__)
   // if physical DVDs, libdvdnav wants "/dev/rdiskN" device name for OSX,
   // strDVDFile will get realloc'ed and replaced IF this is a physical DVD.
-  char* strDVDFile = Cocoa_MountPoint2DeviceName(strdup(path.c_str()));
-  path = strDVDFile;
-  free(strDVDFile);
+  Cocoa_MountPoint2DeviceName(strDVDFile);
 #endif
 
   // open up the DVD device
-  if (m_dll.dvdnav_open(&m_dvdnav, path.c_str()) != DVDNAV_STATUS_OK)
+  if (m_dll.dvdnav_open(&m_dvdnav, strDVDFile) != DVDNAV_STATUS_OK)
   {
+    free(strDVDFile);
+
     CLog::Log(LOGERROR,"Error on dvdnav_open\n");
     Close();
     return false;
   }
+  free(strDVDFile);
 
-  int region = CSettings::Get().GetInt("dvds.playerregion");
+  int region = g_guiSettings.GetInt("dvds.playerregion");
   int mask = 0;
   if(region > 0)
     mask = 1 << (region-1);
@@ -177,7 +175,7 @@ bool CDVDInputStreamNavigator::Open(const char* strFile, const std::string& cont
   }
 
   // jump directly to title menu
-  if(CSettings::Get().GetBool("dvds.automenu"))
+  if(g_guiSettings.GetBool("dvds.automenu"))
   {
     int len, event;
     uint8_t buf[2048];
@@ -187,14 +185,8 @@ bool CDVDInputStreamNavigator::Open(const char* strFile, const std::string& cont
     m_dll.dvdnav_get_next_cache_block(m_dvdnav,&buf_ptr,&event,&len);
     m_dll.dvdnav_sector_search(m_dvdnav, 0, SEEK_SET);
 
-    // first try title menu
     if(m_dll.dvdnav_menu_call(m_dvdnav, DVD_MENU_Title) != DVDNAV_STATUS_OK)
-    {
       CLog::Log(LOGERROR,"Error on dvdnav_menu_call(Title): %s\n", m_dll.dvdnav_err_to_string(m_dvdnav));
-      // next try root menu
-      if(m_dll.dvdnav_menu_call(m_dvdnav, DVD_MENU_Root) != DVDNAV_STATUS_OK )
-        CLog::Log(LOGERROR,"Error on dvdnav_menu_call(Root): %s\n", m_dll.dvdnav_err_to_string(m_dvdnav));
-    }
   }
 
   m_bEOF = false;
@@ -228,7 +220,7 @@ void CDVDInputStreamNavigator::Close()
   m_bEOF = true;
 }
 
-int CDVDInputStreamNavigator::Read(uint8_t* buf, int buf_size)
+int CDVDInputStreamNavigator::Read(BYTE* buf, int buf_size)
 {
   if (!m_dvdnav || m_bEOF) return 0;
   if (buf_size < DVD_VIDEO_BLOCKSIZE)
@@ -237,61 +229,74 @@ int CDVDInputStreamNavigator::Read(uint8_t* buf, int buf_size)
     return -1;
   }
 
+  int navresult;
   int iBytesRead;
 
-  int NOPcount = 0;
   while(true) {
-    int navresult = ProcessBlock(buf, &iBytesRead);
+    navresult = ProcessBlock(buf, &iBytesRead);
     if (navresult == NAVRESULT_HOLD)       return 0; // return 0 bytes read;
     else if (navresult == NAVRESULT_ERROR) return -1;
     else if (navresult == NAVRESULT_DATA)  return iBytesRead;
-    else if (navresult == NAVRESULT_NOP)
-    {
-      NOPcount++;
-      if (NOPcount == 1000) 
-      {
-        m_bEOF = true;
-        CLog::Log(LOGERROR,"CDVDInputStreamNavigator: Stopping playback due to infinite loop, caused by badly authored DVD navigation structure. Try enabling 'Attempt to skip introduction before DVD menu'.");
-        m_pDVDPlayer->OnDVDNavResult(NULL, DVDNAV_STOP);
-        return -1; // fail and stop playback.
-      }
-    }
   }
 
   return iBytesRead;
 }
 
 // not working yet, but it is the recommanded way for seeking
-int64_t CDVDInputStreamNavigator::Seek(int64_t offset, int whence)
+__int64 CDVDInputStreamNavigator::Seek(__int64 offset, int whence)
 {
-  if(whence == SEEK_POSSIBLE)
-    return 0;
+  if (!m_dvdnav) return -1;
+  uint32_t pos=0, len=1;
+  if (m_dll.dvdnav_sector_search(m_dvdnav, (uint64_t)(offset / DVD_VIDEO_LB_LEN), (int32_t)whence) != DVDNAV_STATUS_ERR)
+  {
+    m_dll.dvdnav_get_position(m_dvdnav, &pos, &len);
+  }
   else
+  {
+    CLog::Log(LOGDEBUG, "dvdnav: %s", m_dll.dvdnav_err_to_string(m_dvdnav));
     return -1;
+  }
+
+  return (int)(pos * DVD_VIDEO_LB_LEN);
 }
 
-int CDVDInputStreamNavigator::ProcessBlock(uint8_t* dest_buffer, int* read)
+int CDVDInputStreamNavigator::ProcessBlock(BYTE* dest_buffer, int* read)
 {
   if (!m_dvdnav) return -1;
 
   int result;
-  int len = 2048;
+  int len;
+  int iNavresult = NAVRESULT_NOP;
 
   // m_tempbuffer will be used for anything that isn't a normal data block
   uint8_t* buf = m_lastblock;
-  int iNavresult = -1;
+  iNavresult = -1;
 
   if(m_holdmode == HOLDMODE_HELD)
     return NAVRESULT_HOLD;
 
-  // the main reading function
-  if(m_holdmode == HOLDMODE_SKIP)
-  { /* we where holding data, return the data held */
-    m_holdmode = HOLDMODE_DATA;
-    result = DVDNAV_STATUS_OK;
+  try
+  {
+    // the main reading function
+    if(m_holdmode == HOLDMODE_SKIP)
+    { /* we where holding data, return the data held */
+      m_holdmode = HOLDMODE_DATA;
+      result = DVDNAV_STATUS_OK;
+    }
+    else
+      result = m_dll.dvdnav_get_next_cache_block(m_dvdnav, &buf, &m_lastevent, &len);
+
+  }
+  catch (...)
+  {
+    CLog::Log(LOGERROR, "CDVDInputStreamNavigator::ProcessBlock - exception thrown in dvdnav_get_next_cache_block.");
+
+    // okey, we are probably holding a vm_lock here so leave it.. this could potentialy cause problems if we aren't holding it
+    // but it's more likely that we do
+    LeaveCriticalSection((LPCRITICAL_SECTION)&(m_dvdnav->vm_lock));
+    m_bEOF = true;
+    return NAVRESULT_ERROR;
   }
-  else
-    result = m_dll.dvdnav_get_next_cache_block(m_dvdnav, &buf, &m_lastevent, &len);
 
   if (result == DVDNAV_STATUS_ERR)
   {
@@ -324,7 +329,6 @@ int CDVDInputStreamNavigator::ProcessBlock(uint8_t* dest_buffer, int* read)
         // user input to make menus and other interactive stills work.
         // A length of 0xff means an indefinite still which has to be skipped
         // indirectly by some user interaction.
-        m_holdmode = HOLDMODE_NONE;
         iNavresult = m_pDVDPlayer->OnDVDNavResult(buf, DVDNAV_STILL_FRAME);
 
         /* if user didn't care for action, just skip it */
@@ -372,20 +376,6 @@ int CDVDInputStreamNavigator::ProcessBlock(uint8_t* dest_buffer, int* read)
         //libdvdnav never sets logical, why.. don't know..
         event->logical = GetActiveSubtitleStream();
 
-        /* correct stream ids for disabled subs if needed */
-        if(!IsSubtitleStreamEnabled())
-        {
-          event->physical_letterbox |= 0x80;
-          event->physical_pan_scan |= 0x80;
-          event->physical_wide |= 0x80;
-        }
-
-        if(event->logical<0 && GetSubTitleStreamCount()>0)
-        {
-          /* this will not take effect in this event */
-          CLog::Log(LOGINFO, "%s - none or invalid subtitle stream selected, defaulting to first", __FUNCTION__);
-          SetActiveSubtitleStream(0);
-        }
         m_bCheckButtons = true;
         iNavresult = m_pDVDPlayer->OnDVDNavResult(buf, DVDNAV_SPU_STREAM_CHANGE);
       }
@@ -437,10 +427,9 @@ int CDVDInputStreamNavigator::ProcessBlock(uint8_t* dest_buffer, int* read)
           iNavresult = NAVRESULT_HOLD;
         }
         else
-        {
-          m_bInMenu   = (0 == m_dll.dvdnav_is_domain_vts(m_dvdnav));
           iNavresult = m_pDVDPlayer->OnDVDNavResult(buf, DVDNAV_VTS_CHANGE);
-        }
+
+        m_bInMenu = (0 == m_dll.dvdnav_is_domain_vts(m_dvdnav));
       }
       break;
 
@@ -477,8 +466,8 @@ int CDVDInputStreamNavigator::ProcessBlock(uint8_t* dest_buffer, int* read)
 
         dvdnav_cell_change_event_t* cell_change_event = (dvdnav_cell_change_event_t*)buf;
         m_iCellStart = cell_change_event->cell_start; // store cell time as we need that for time later
-        m_iTime      = (int) (m_iCellStart / 90);
         m_iTotalTime = (int) (cell_change_event->pgc_length / 90);
+        m_icurrentGroupId = cell_change_event->pgN * 1000 + cell_change_event->cellN;
 
         iNavresult = m_pDVDPlayer->OnDVDNavResult(buf, DVDNAV_CELL_CHANGE);
       }
@@ -500,7 +489,7 @@ int CDVDInputStreamNavigator::ProcessBlock(uint8_t* dest_buffer, int* read)
         // Calculate current time
         //unsigned int pos, len;
         //m_dll.dvdnav_get_position(m_dvdnav, &pos, &len);
-        //m_iTime = (int)(((int64_t)m_iTotalTime * pos) / len);
+        //m_iTime = (int)(((__int64)m_iTotalTime * pos) / len);
 
         pci_t* pci = m_dll.dvdnav_get_current_nav_pci(m_dvdnav);
         m_dll.dvdnav_get_current_nav_dsi(m_dvdnav);
@@ -515,7 +504,7 @@ int CDVDInputStreamNavigator::ProcessBlock(uint8_t* dest_buffer, int* read)
         m_bInMenu = pci->hli.hl_gi.hli_ss || (0 == m_dll.dvdnav_is_domain_vts(m_dvdnav));
 
         /* check for any gap in the stream, this is likely a discontinuity */
-        int64_t gap = (int64_t)pci->pci_gi.vobu_s_ptm - m_iVobUnitStop;
+        __int64 gap = (__int64)pci->pci_gi.vobu_s_ptm - m_iVobUnitStop;
         if(gap)
         {
           /* make sure demuxer is flushed before we change any correction */
@@ -528,7 +517,7 @@ int CDVDInputStreamNavigator::ProcessBlock(uint8_t* dest_buffer, int* read)
           }
           m_iVobUnitCorrection += gap;
 
-          CLog::Log(LOGDEBUG, "DVDNAV_NAV_PACKET - DISCONTINUITY FROM:%"PRId64" TO:%"PRId64" DIFF:%"PRId64, (m_iVobUnitStop * 1000)/90, ((int64_t)pci->pci_gi.vobu_s_ptm*1000)/90, (gap*1000)/90);
+          CLog::Log(LOGDEBUG, "DVDNAV_NAV_PACKET - DISCONTINUITY FROM:%"PRId64" TO:%"PRId64" DIFF:%"PRId64, (m_iVobUnitStop * 1000)/90, ((__int64)pci->pci_gi.vobu_s_ptm*1000)/90, (gap*1000)/90);
         }
 
         m_iVobUnitStart = pci->pci_gi.vobu_s_ptm;
@@ -776,7 +765,7 @@ void CDVDInputStreamNavigator::OnBack()
 // we don't allow skipping in menu's cause it will remove menu overlays
 void CDVDInputStreamNavigator::OnNext()
 {
-  if (m_dvdnav && !(IsInMenu() && GetTotalButtons() > 0))
+  if (m_dvdnav && !IsInMenu())
   {
     m_dll.dvdnav_next_pg_search(m_dvdnav);
   }
@@ -785,7 +774,7 @@ void CDVDInputStreamNavigator::OnNext()
 // we don't allow skipping in menu's cause it will remove menu overlays
 void CDVDInputStreamNavigator::OnPrevious()
 {
-  if (m_dvdnav && !(IsInMenu() && GetTotalButtons() > 0))
+  if (m_dvdnav && !IsInMenu())
   {
     m_dll.dvdnav_prev_pg_search(m_dvdnav);
   }
@@ -803,17 +792,15 @@ void CDVDInputStreamNavigator::SkipWait()
   m_dll.dvdnav_wait_skip(m_dvdnav);
 }
 
-CDVDInputStream::ENextStream CDVDInputStreamNavigator::NextStream()
+void CDVDInputStreamNavigator::SkipHold()
 {
-  if(m_holdmode == HOLDMODE_HELD)
+  if(IsHeld())
     m_holdmode = HOLDMODE_SKIP;
+}
 
-  if(m_bEOF)
-    return NEXTSTREAM_NONE;
-  else if(m_lastevent == DVDNAV_VTS_CHANGE)
-    return NEXTSTREAM_OPEN;
-  else
-    return NEXTSTREAM_RETRY;
+bool CDVDInputStreamNavigator::IsHeld()
+{
+  return m_holdmode == HOLDMODE_HELD;
 }
 
 int CDVDInputStreamNavigator::GetActiveSubtitleStream()
@@ -845,61 +832,52 @@ int CDVDInputStreamNavigator::GetActiveSubtitleStream()
   return activeStream;
 }
 
-bool CDVDInputStreamNavigator::GetSubtitleStreamInfo(const int iId, DVDNavStreamInfo &info)
+std::string CDVDInputStreamNavigator::GetSubtitleStreamLanguage(int iId)
 {
-  if (!m_dvdnav) return false;
+  if (!m_dvdnav) return NULL;
+
+  CStdString strLanguage;
 
-  int streamId = ConvertSubtitleStreamId_XBMCToExternal(iId);
   subp_attr_t subp_attributes;
-
-  if( m_dll.dvdnav_get_spu_attr(m_dvdnav, streamId, &subp_attributes) == DVDNAV_STATUS_OK )
+  int streamId = ConvertSubtitleStreamId_XBMCToExternal(iId);
+  if( m_dll.dvdnav_get_stitle_info(m_dvdnav, streamId, &subp_attributes) == DVDNAV_STATUS_OK )
   {
-    SetSubtitleStreamName(info, subp_attributes);
 
-    char lang[3];
-    lang[2] = 0;
-    lang[1] = (subp_attributes.lang_code & 255);
-    lang[0] = (subp_attributes.lang_code >> 8) & 255;
-
-    CStdString temp;
-    g_LangCodeExpander.ConvertToThreeCharCode(temp, lang);
-    info.language = temp;
-
-    return true;
-  }
-  return false;
-}
-
-void CDVDInputStreamNavigator::SetSubtitleStreamName(DVDNavStreamInfo &info, const subp_attr_t &subp_attributes)
-{
-  if (subp_attributes.type == DVD_SUBPICTURE_TYPE_Language ||
-    subp_attributes.type == DVD_SUBPICTURE_TYPE_NotSpecified)
-  {
-    switch (subp_attributes.lang_extension)
+    if (subp_attributes.type == DVD_SUBPICTURE_TYPE_Language ||
+        subp_attributes.type == DVD_SUBPICTURE_TYPE_NotSpecified)
     {
-    case DVD_SUBPICTURE_LANG_EXT_NotSpecified:
-    case DVD_SUBPICTURE_LANG_EXT_NormalCaptions:
-    case DVD_SUBPICTURE_LANG_EXT_BigCaptions:
-    case DVD_SUBPICTURE_LANG_EXT_ChildrensCaptions:
-      break;
+      if (!g_LangCodeExpander.Lookup(strLanguage, subp_attributes.lang_code)) strLanguage = "Unknown";
 
-    case DVD_SUBPICTURE_LANG_EXT_NormalCC:
-    case DVD_SUBPICTURE_LANG_EXT_BigCC:
-    case DVD_SUBPICTURE_LANG_EXT_ChildrensCC:
-      info.name += g_localizeStrings.Get(37011);
-      break;
-    case DVD_SUBPICTURE_LANG_EXT_Forced:
-      info.name += g_localizeStrings.Get(37012);
-      break;
-    case DVD_SUBPICTURE_LANG_EXT_NormalDirectorsComments:
-    case DVD_SUBPICTURE_LANG_EXT_BigDirectorsComments:
-    case DVD_SUBPICTURE_LANG_EXT_ChildrensDirectorsComments:
-      info.name += g_localizeStrings.Get(37013);
-      break;
-    default:
-      break;
+      switch (subp_attributes.lang_extension)
+      {
+        case DVD_SUBPICTURE_LANG_EXT_NotSpecified:
+        case DVD_SUBPICTURE_LANG_EXT_NormalCaptions:
+        case DVD_SUBPICTURE_LANG_EXT_BigCaptions:
+        case DVD_SUBPICTURE_LANG_EXT_ChildrensCaptions:
+          break;
+
+        case DVD_SUBPICTURE_LANG_EXT_NormalCC:
+        case DVD_SUBPICTURE_LANG_EXT_BigCC:
+        case DVD_SUBPICTURE_LANG_EXT_ChildrensCC:
+          strLanguage+= " (CC)";
+          break;
+        case DVD_SUBPICTURE_LANG_EXT_Forced:
+          strLanguage+= " (Forced)";
+          break;
+        case DVD_SUBPICTURE_LANG_EXT_NormalDirectorsComments:
+        case DVD_SUBPICTURE_LANG_EXT_BigDirectorsComments:
+        case DVD_SUBPICTURE_LANG_EXT_ChildrensDirectorsComments:
+          strLanguage+= " (Directors Comments)";
+          break;
+      }
+    }
+    else
+    {
+      strLanguage = "Unknown";
     }
   }
+
+  return strLanguage;
 }
 
 int CDVDInputStreamNavigator::GetSubTitleStreamCount()
@@ -957,105 +935,37 @@ int CDVDInputStreamNavigator::GetActiveAudioStream()
   return activeStream;
 }
 
-void CDVDInputStreamNavigator::SetAudioStreamName(DVDNavStreamInfo &info, const audio_attr_t &audio_attributes)
+std::string CDVDInputStreamNavigator::GetAudioStreamLanguage(int iId)
 {
-  switch( audio_attributes.code_extension )
-  {
-  case DVD_AUDIO_LANG_EXT_VisuallyImpaired:
-    info.name = g_localizeStrings.Get(37000);
-    break;
-  case DVD_AUDIO_LANG_EXT_DirectorsComments1:
-    info.name = g_localizeStrings.Get(37001);
-    break;
-  case DVD_AUDIO_LANG_EXT_DirectorsComments2:
-    info.name = g_localizeStrings.Get(37002);
-    break;
-  case DVD_AUDIO_LANG_EXT_NotSpecified:
-  case DVD_AUDIO_LANG_EXT_NormalCaptions:
-  default:
-    break;
-  }
+  if (!m_dvdnav) return NULL;
 
-  switch(audio_attributes.audio_format)
-  {
-  case DVD_AUDIO_FORMAT_AC3:
-    info.name += " AC3";
-    break;
-  case DVD_AUDIO_FORMAT_UNKNOWN_1:
-    info.name += " UNKNOWN #1";
-    break;
-  case DVD_AUDIO_FORMAT_MPEG:
-    info.name += " MPEG AUDIO";
-    break;
-  case DVD_AUDIO_FORMAT_MPEG2_EXT:
-    info.name += " MP2 Ext.";
-    break;
-  case DVD_AUDIO_FORMAT_LPCM:
-    info.name += " LPCM";
-    break;
-  case DVD_AUDIO_FORMAT_UNKNOWN_5:
-    info.name += " UNKNOWN #5";
-    break;
-  case DVD_AUDIO_FORMAT_DTS:
-    info.name += " DTS";
-    break;
-  case DVD_AUDIO_FORMAT_SDDS:
-    info.name += " SDDS";
-    break;
-  default:
-    info.name += " Other";
-    break;
-  }
+  CStdString strLanguage;
 
-  switch(audio_attributes.channels + 1)
-  {
-  case 1:
-    info.name += " Mono";
-    break;
-  case 2: 
-    info.name += " Stereo";
-    break;
-  case 6: 
-    info.name += " 5.1";
-    break;
-  case 7:
-    info.name += " 6.1";
-    break;
-  default:
-    char temp[32];
-    sprintf(temp, " %d-chs", audio_attributes.channels + 1);
-    info.name += temp;
-  }
-
-  StringUtils::TrimLeft(info.name);
-
-}
-
-bool CDVDInputStreamNavigator::GetAudioStreamInfo(const int iId, DVDNavStreamInfo &info)
-{
-  if (!m_dvdnav) return false;
-
-  int streamId = ConvertAudioStreamId_XBMCToExternal(iId);
   audio_attr_t audio_attributes;
-
-  if( m_dll.dvdnav_get_audio_attr(m_dvdnav, streamId, &audio_attributes) == DVDNAV_STATUS_OK )
+  int streamId = ConvertAudioStreamId_XBMCToExternal(iId);
+  if( m_dll.dvdnav_get_audio_info(m_dvdnav, streamId, &audio_attributes) == DVDNAV_STATUS_OK )
   {
-    SetAudioStreamName(info, audio_attributes);
+    if (!g_LangCodeExpander.Lookup(strLanguage, audio_attributes.lang_code)) strLanguage = "Unknown";
 
-    char lang[3];
-    lang[2] = 0;
-    lang[1] = (audio_attributes.lang_code & 255);
-    lang[0] = (audio_attributes.lang_code >> 8) & 255;
-
-    CStdString temp;
-    g_LangCodeExpander.ConvertToThreeCharCode(temp, lang);
-    info.language = temp;
-
-    info.channels = audio_attributes.channels + 1;
-
-    return true;
+    switch( audio_attributes.lang_extension )
+    {
+      case DVD_AUDIO_LANG_EXT_VisuallyImpaired:
+        strLanguage+= " (Visually Impaired)";
+        break;
+      case DVD_AUDIO_LANG_EXT_DirectorsComments1:
+        strLanguage+= " (Directors Comments)";
+        break;
+      case DVD_AUDIO_LANG_EXT_DirectorsComments2:
+        strLanguage+= " (Directors Comments 2)";
+        break;
+      case DVD_AUDIO_LANG_EXT_NotSpecified:
+      case DVD_AUDIO_LANG_EXT_NormalCaptions:
+      default:
+        break;
+    }
   }
-  return false;
+
+  return strLanguage;
 }
 
 int CDVDInputStreamNavigator::GetAudioStreamCount()
@@ -1135,7 +1045,7 @@ int CDVDInputStreamNavigator::GetTime()
 
 bool CDVDInputStreamNavigator::SeekTime(int iTimeInMsec)
 {
-  if( m_dll.dvdnav_jump_to_sector_by_time(m_dvdnav, iTimeInMsec * 90, 0) == DVDNAV_STATUS_ERR )
+  if( m_dll.dvdnav_time_search(m_dvdnav, iTimeInMsec * 90) == DVDNAV_STATUS_ERR )
   {
     CLog::Log(LOGDEBUG, "dvdnav: dvdnav_time_search failed( %s )", m_dll.dvdnav_err_to_string(m_dvdnav));
     return false;
@@ -1145,48 +1055,12 @@ bool CDVDInputStreamNavigator::SeekTime(int iTimeInMsec)
 
 bool CDVDInputStreamNavigator::SeekChapter(int iChapter)
 {
-  if (!m_dvdnav)
-    return false;
-
-  // cannot allow to return true in case of buttons (overlays) because otherwise back in DVDPlayer FlushBuffers will remove menu overlays
-  // therefore we just skip the request in case there are buttons and return false
-  if (IsInMenu() && GetTotalButtons() > 0)
-  {
-    CLog::Log(LOGDEBUG, "%s - Seeking chapter is not allowed in menu set with buttons", __FUNCTION__);
-    return false;
-  }
-
-  bool enabled = IsSubtitleStreamEnabled();
-  int audio    = GetActiveAudioStream();
-  int subtitle = GetActiveSubtitleStream();
-
-  if (iChapter == (m_iPart + 1))
-  {
-    if (m_dll.dvdnav_next_pg_search(m_dvdnav) == DVDNAV_STATUS_ERR)
-    {
-      CLog::Log(LOGERROR, "dvdnav: dvdnav_next_pg_search( %s )", m_dll.dvdnav_err_to_string(m_dvdnav));
-      return false;
-    }
-  }
-  else
-  if (iChapter == (m_iPart - 1))
-  {
-    if (m_dll.dvdnav_prev_pg_search(m_dvdnav) == DVDNAV_STATUS_ERR)
-    {
-      CLog::Log(LOGERROR, "dvdnav: dvdnav_prev_pg_search( %s )", m_dll.dvdnav_err_to_string(m_dvdnav));
-      return false;
-    }
-  }
-  else  
   if (m_dll.dvdnav_part_play(m_dvdnav, m_iTitle, iChapter) == DVDNAV_STATUS_ERR)
   {
     CLog::Log(LOGERROR, "dvdnav: dvdnav_part_play failed( %s )", m_dll.dvdnav_err_to_string(m_dvdnav));
     return false;
   }
 
-  SetActiveSubtitleStream(subtitle);
-  SetActiveAudioStream(audio);
-  EnableSubtitleStream(enabled);
   return true;
 }
 
@@ -1244,7 +1118,7 @@ bool CDVDInputStreamNavigator::IsSubtitleStreamEnabled()
     return false;
 }
 
-bool CDVDInputStreamNavigator::GetState(std::string &xmlstate)
+bool CDVDInputStreamNavigator::GetNavigatorState(std::string &xmlstate)
 {
   if( !m_dvdnav )
     return false;
@@ -1265,7 +1139,7 @@ bool CDVDInputStreamNavigator::GetState(std::string &xmlstate)
   return true;
 }
 
-bool CDVDInputStreamNavigator::SetState(const std::string &xmlstate)
+bool CDVDInputStreamNavigator::SetNavigatorState(std::string &xmlstate)
 {
   if( !m_dvdnav )
     return false;
@@ -1284,7 +1158,7 @@ bool CDVDInputStreamNavigator::SetState(const std::string &xmlstate)
     CLog::Log(LOGWARNING, "CDVDInputStreamNavigator::SetNavigatorState - Failed to set state (%s), retrying after read", m_dll.dvdnav_err_to_string(m_dvdnav));
 
     /* vm won't be started until after first read, this should really be handled internally */
-    uint8_t buffer[DVD_VIDEO_BLOCKSIZE];
+    BYTE buffer[DVD_VIDEO_BLOCKSIZE];
     Read(buffer,DVD_VIDEO_BLOCKSIZE);
 
     if( DVDNAV_STATUS_ERR == m_dll.dvdnav_set_state(m_dvdnav, &save_state) )
@@ -1365,6 +1239,9 @@ int CDVDInputStreamNavigator::ConvertAudioStreamId_ExternalToXBMC(int id)
     // non VTS_DOMAIN, only one stream is available
     return 0;
   }
+
+  CLog::Log(LOGWARNING, "%s - no stream found %d", __FUNCTION__, id);
+  return -1;
 }
 
 int CDVDInputStreamNavigator::ConvertSubtitleStreamId_XBMCToExternal(int id)
@@ -1436,22 +1313,7 @@ int CDVDInputStreamNavigator::ConvertSubtitleStreamId_ExternalToXBMC(int id)
     // non VTS_DOMAIN, only one stream is available
     return 0;
   }
-}
 
-bool CDVDInputStreamNavigator::GetDVDTitleString(std::string& titleStr)
-{
-  if (!m_dvdnav) return false;
-  const char* str = NULL;
-  m_dll.dvdnav_get_title_string(m_dvdnav, &str);
-  titleStr.assign(str);
-  return true;
-}
-
-bool CDVDInputStreamNavigator::GetDVDSerialString(std::string& serialStr)
-{
-  if (!m_dvdnav) return false;
-  const char* str = NULL;
-  m_dll.dvdnav_get_serial_string(m_dvdnav, &str);
-  serialStr.assign(str);
-  return true;
+  CLog::Log(LOGWARNING, "%s - no stream found %d", __FUNCTION__, id);
+  return -1;
 }
