@@ -1,8 +1,8 @@
 #pragma once
 
 /*
- *      Copyright (C) 2005-2013 Team XBMC
- *      http://xbmc.org
+ *      Copyright (C) 2005-2008 Team XBMC
+ *      http://www.xbmc.org
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,21 +15,22 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with XBMC; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
+ *  along with XBMC; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  http://www.gnu.org/copyleft/gpl.html
  *
  */
 
 extern "C" {
 #define DVDNAV_COMPILE
  #include <stdint.h>
-
+ 
  #include "dvdnav/dvdnav.h"
 
  #ifndef WIN32
  #define WIN32
  #endif // WIN32
-
+ 
  #ifndef HAVE_CONFIG_H
  #define HAVE_CONFIG_H
  #endif
@@ -86,6 +87,8 @@ public:
   virtual int8_t dvdnav_get_active_audio_stream(dvdnav_t *self)=0;
   virtual uint16_t dvdnav_audio_stream_to_lang(dvdnav_t *self, uint8_t stream)=0;
   virtual vm_t* dvdnav_get_vm(dvdnav_t *self)=0;
+  virtual int dvdnav_get_nr_of_subtitle_streams(dvdnav_t *self)=0;
+  virtual int dvdnav_get_nr_of_audio_streams(dvdnav_t *self)=0;
   virtual int dvdnav_get_button_info(dvdnav_t* self, int alpha[2][4], int color[2][4])=0;
   virtual int8_t dvdnav_get_audio_logical_stream(dvdnav_t *self, uint8_t audio_num)=0;
   virtual dvdnav_status_t dvdnav_set_region_mask(dvdnav_t *self, int32_t region_mask)=0;
@@ -95,8 +98,10 @@ public:
   virtual dvdnav_status_t dvdnav_get_number_of_parts(dvdnav_t *self, int32_t title, int32_t *parts)=0;
   virtual dvdnav_status_t dvdnav_title_play(dvdnav_t *self, int32_t title)=0;
   virtual dvdnav_status_t dvdnav_part_play(dvdnav_t *self, int32_t title, int32_t part)=0;
-  virtual dvdnav_status_t dvdnav_get_audio_attr(dvdnav_t * self, int32_t streamid, audio_attr_t* audio_attributes)=0;
-  virtual dvdnav_status_t dvdnav_get_spu_attr(dvdnav_t * self, int32_t streamid, subp_attr_t* stitle_attributes)=0;
+  virtual dvdnav_status_t dvdnav_subpicture_change(dvdnav_t *self, int32_t subpicture)=0;
+  virtual dvdnav_status_t dvdnav_audio_change(dvdnav_t *self, int32_t audio)=0;
+  virtual dvdnav_status_t dvdnav_get_audio_info(dvdnav_t * self, int32_t streamid, audio_attr_t* audio_attributes)=0;
+  virtual dvdnav_status_t dvdnav_get_stitle_info(dvdnav_t * self, int32_t streamid, subp_attr_t* stitle_attributes)=0;
   virtual dvdnav_status_t dvdnav_time_search(dvdnav_t * self, uint64_t timepos)=0;
   virtual int64_t dvdnav_convert_time(dvd_time_t *time)=0;
   virtual dvdnav_status_t dvdnav_get_state(dvdnav_t *self, dvd_state_t *save_state)=0;
@@ -104,8 +109,6 @@ public:
   virtual dvdnav_status_t dvdnav_get_angle_info(dvdnav_t *self, int32_t *current_angle,int32_t *number_of_angles)=0;
   virtual dvdnav_status_t dvdnav_mouse_activate(dvdnav_t *self, pci_t *pci, int32_t x, int32_t y)=0;
   virtual dvdnav_status_t dvdnav_mouse_select(dvdnav_t *self, pci_t *pci, int32_t x, int32_t y)=0;
-  virtual dvdnav_status_t dvdnav_get_title_string(dvdnav_t *self, const char **title_str)=0;
-  virtual dvdnav_status_t dvdnav_get_serial_string(dvdnav_t *self, const char **serial_str)=0;
 };
 
 #if (defined USE_STATIC_LIBDVDNAV)
@@ -191,6 +194,10 @@ public:
         { return ::dvdnav_audio_stream_to_lang(self, stream); }
     virtual vm_t* dvdnav_get_vm(dvdnav_t *self)
         { return ::dvdnav_get_vm(self); }
+    virtual int dvdnav_get_nr_of_subtitle_streams(dvdnav_t *self)
+        { return ::dvdnav_get_nr_of_subtitle_streams(self); }
+    virtual int dvdnav_get_nr_of_audio_streams(dvdnav_t *self)
+        { return ::dvdnav_get_nr_of_audio_streams(self); }
     virtual int dvdnav_get_button_info(dvdnav_t* self, int alpha[2][4], int color[2][4])
         { return ::dvdnav_get_button_info(self, alpha, color); }
     virtual int8_t dvdnav_get_audio_logical_stream(dvdnav_t *self, uint8_t audio_num)
@@ -209,10 +216,14 @@ public:
         { return ::dvdnav_title_play(self, title); }
     virtual dvdnav_status_t dvdnav_part_play(dvdnav_t *self, int32_t title, int32_t part)
         { return ::dvdnav_part_play(self, title, part); }
-    virtual dvdnav_status_t dvdnav_get_audio_attr(dvdnav_t * self, int32_t streamid, audio_attr_t* audio_attributes)
-        { return ::dvdnav_get_audio_attr(self, streamid, audio_attributes); }
-    virtual dvdnav_status_t dvdnav_get_spu_attr(dvdnav_t * self, int32_t streamid, subp_attr_t* stitle_attributes)
-        { return ::dvdnav_get_spu_attr(self, streamid, stitle_attributes); }
+    virtual dvdnav_status_t dvdnav_subpicture_change(dvdnav_t *self, int32_t subpicture)
+        { return ::dvdnav_subpicture_change(self, subpicture); }
+    virtual dvdnav_status_t dvdnav_audio_change(dvdnav_t *self, int32_t audio)
+        { return ::dvdnav_audio_change(self, audio); }
+    virtual dvdnav_status_t dvdnav_get_audio_info(dvdnav_t * self, int32_t streamid, audio_attr_t* audio_attributes)
+        { return ::dvdnav_get_audio_info(self, streamid, audio_attributes); }
+    virtual dvdnav_status_t dvdnav_get_stitle_info(dvdnav_t * self, int32_t streamid, subp_attr_t* stitle_attributes)
+        { return ::dvdnav_get_stitle_info(self, streamid, stitle_attributes); }
     virtual dvdnav_status_t dvdnav_time_search(dvdnav_t * self, uint64_t timepos)
         { return ::dvdnav_time_search(self, timepos); }
     virtual int64_t dvdnav_convert_time(dvd_time_t *time)
@@ -227,10 +238,6 @@ public:
         { return ::dvdnav_mouse_activate(self, pci, x, y); }
     virtual dvdnav_status_t dvdnav_mouse_select(dvdnav_t *self, pci_t *pci, int32_t x, int32_t y)
         { return ::dvdnav_mouse_select(self, pci, x, y); }
-    virtual dvdnav_status_t dvdnav_get_title_string(dvdnav_t *self, const char **title_str)
-        { return ::dvdnav_get_title_string(self, title_str); }
-    virtual dvdnav_status_t dvdnav_get_serial_string(dvdnav_t *self, const char **serial_str)
-        { return ::dvdnav_get_serial_string(self, serial_str); }
 
     // DLL faking.
     virtual bool ResolveExports() { return true; }
@@ -282,6 +289,8 @@ class DllDvdNav : public DllDynamic, DllDvdNavInterface
   DEFINE_METHOD1(int8_t, dvdnav_get_active_audio_stream, (dvdnav_t *p1))
   DEFINE_METHOD2(uint16_t, dvdnav_audio_stream_to_lang, (dvdnav_t *p1, uint8_t p2))
   DEFINE_METHOD1(vm_t*, dvdnav_get_vm, (dvdnav_t *p1))
+  DEFINE_METHOD1(int, dvdnav_get_nr_of_subtitle_streams, (dvdnav_t *p1))
+  DEFINE_METHOD1(int, dvdnav_get_nr_of_audio_streams, (dvdnav_t *p1))
   DEFINE_METHOD3(int, dvdnav_get_button_info, (dvdnav_t* p1, int p2[2][4], int p3[2][4]))
   DEFINE_METHOD2(int8_t, dvdnav_get_audio_logical_stream, (dvdnav_t *p1, uint8_t p2))
   DEFINE_METHOD2(dvdnav_status_t, dvdnav_set_region_mask, (dvdnav_t *p1, int32_t p2))
@@ -291,18 +300,17 @@ class DllDvdNav : public DllDynamic, DllDvdNavInterface
   DEFINE_METHOD3(dvdnav_status_t, dvdnav_get_number_of_parts, (dvdnav_t *p1, int32_t p2, int32_t *p3))
   DEFINE_METHOD2(dvdnav_status_t, dvdnav_title_play, (dvdnav_t *p1, int32_t p2))
   DEFINE_METHOD3(dvdnav_status_t, dvdnav_part_play, (dvdnav_t *p1, int32_t p2, int32_t p3))
-  DEFINE_METHOD3(dvdnav_status_t, dvdnav_get_audio_attr, (dvdnav_t * p1, int32_t p2, audio_attr_t* p3))
-  DEFINE_METHOD3(dvdnav_status_t, dvdnav_get_spu_attr, (dvdnav_t * p1, int32_t p2, subp_attr_t* p3))
+  DEFINE_METHOD2(dvdnav_status_t, dvdnav_subpicture_change, (dvdnav_t *p1, int32_t p2))
+  DEFINE_METHOD2(dvdnav_status_t, dvdnav_audio_change, (dvdnav_t *p1, int32_t p2))
+  DEFINE_METHOD3(dvdnav_status_t, dvdnav_get_audio_info, (dvdnav_t * p1, int32_t p2, audio_attr_t* p3))
+  DEFINE_METHOD3(dvdnav_status_t, dvdnav_get_stitle_info, (dvdnav_t * p1, int32_t p2, subp_attr_t* p3))
   DEFINE_METHOD2(dvdnav_status_t, dvdnav_time_search, (dvdnav_t * p1, uint64_t p2))
-  DEFINE_METHOD3(dvdnav_status_t, dvdnav_jump_to_sector_by_time, (dvdnav_t * p1, uint64_t p2, int32_t p3))
   DEFINE_METHOD1(int64_t, dvdnav_convert_time, (dvd_time_t *p1))
   DEFINE_METHOD2(dvdnav_status_t, dvdnav_get_state, (dvdnav_t *p1, dvd_state_t *p2))
   DEFINE_METHOD2(dvdnav_status_t, dvdnav_set_state, (dvdnav_t *p1, dvd_state_t *p2))
   DEFINE_METHOD3(dvdnav_status_t, dvdnav_get_angle_info, (dvdnav_t *p1, int32_t *p2,int32_t *p3))
   DEFINE_METHOD4(dvdnav_status_t, dvdnav_mouse_activate, (dvdnav_t *p1, pci_t *p2, int32_t p3, int32_t p4))
   DEFINE_METHOD4(dvdnav_status_t, dvdnav_mouse_select, (dvdnav_t *p1, pci_t *p2, int32_t p3, int32_t p4))
-  DEFINE_METHOD2(dvdnav_status_t, dvdnav_get_title_string, (dvdnav_t *p1, const char **p2))
-  DEFINE_METHOD2(dvdnav_status_t, dvdnav_get_serial_string, (dvdnav_t *p1, const char **p2))
   BEGIN_METHOD_RESOLVE()
     RESOLVE_METHOD(dvdnav_open)
     RESOLVE_METHOD(dvdnav_close)
@@ -342,6 +350,8 @@ class DllDvdNav : public DllDynamic, DllDvdNavInterface
     RESOLVE_METHOD(dvdnav_get_active_audio_stream)
     RESOLVE_METHOD(dvdnav_audio_stream_to_lang)
     RESOLVE_METHOD(dvdnav_get_vm)
+    RESOLVE_METHOD(dvdnav_get_nr_of_subtitle_streams)
+    RESOLVE_METHOD(dvdnav_get_nr_of_audio_streams)
     RESOLVE_METHOD(dvdnav_get_button_info)
     RESOLVE_METHOD(dvdnav_get_audio_logical_stream)
     RESOLVE_METHOD(dvdnav_set_region_mask)
@@ -351,18 +361,17 @@ class DllDvdNav : public DllDynamic, DllDvdNavInterface
     RESOLVE_METHOD(dvdnav_get_number_of_parts)
     RESOLVE_METHOD(dvdnav_title_play)
     RESOLVE_METHOD(dvdnav_part_play)
-    RESOLVE_METHOD(dvdnav_get_audio_attr)
-    RESOLVE_METHOD(dvdnav_get_spu_attr)
+    RESOLVE_METHOD(dvdnav_subpicture_change)
+    RESOLVE_METHOD(dvdnav_audio_change)
+    RESOLVE_METHOD(dvdnav_get_audio_info)
+    RESOLVE_METHOD(dvdnav_get_stitle_info)
     RESOLVE_METHOD(dvdnav_time_search)
-    RESOLVE_METHOD(dvdnav_jump_to_sector_by_time)
     RESOLVE_METHOD(dvdnav_convert_time)
     RESOLVE_METHOD(dvdnav_get_state)
     RESOLVE_METHOD(dvdnav_set_state)
     RESOLVE_METHOD(dvdnav_get_angle_info)
     RESOLVE_METHOD(dvdnav_mouse_activate)
     RESOLVE_METHOD(dvdnav_mouse_select)
-    RESOLVE_METHOD(dvdnav_get_title_string)
-    RESOLVE_METHOD(dvdnav_get_serial_string)
 END_METHOD_RESOLVE()
 };
 
