@@ -1,6 +1,6 @@
 /*
- *      Copyright (C) 2005-2013 Team XBMC
- *      http://xbmc.org
+ *      Copyright (C) 2005-2008 Team XBMC
+ *      http://www.xbmc.org
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,27 +13,24 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with XBMC; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
+ *  along with XBMC; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  http://www.gnu.org/copyleft/gpl.html
  *
  */
 
 #include "Edl.h"
-#include "utils/StringUtils.h"
-#include "utils/URIUtils.h"
-#include "filesystem/File.h"
-#include "filesystem/MythFile.h"
-#include "settings/AdvancedSettings.h"
+#include "StringUtils.h"
+#include "Util.h"
+#include "FileSystem/File.h"
+#include "FileSystem/CMythFile.h"
+#include "AdvancedSettings.h"
 #include "utils/log.h"
-#include "utils/XBMCTinyXML.h"
-#include "PlatformDefs.h"
-#include "URL.h"
-#include "pvr/recordings/PVRRecordings.h"
-#include "pvr/PVRManager.h"
+#include "tinyXML/tinyxml.h"
 
 extern "C"
 {
-#include "cmyth/include/cmyth/cmyth.h"
+#include "lib/libcmyth/cmyth.h"
 }
 
 using namespace std;
@@ -66,63 +63,19 @@ void CEdl::Clear()
   m_iTotalCutTime = 0;
 }
 
-bool CEdl::ReadEditDecisionLists(const CStdString& strMovie, const float fFrameRate, const int iHeight)
+bool CEdl::ReadEditDecisionLists(const CStdString& strMovie, const float fFramesPerSecond)
 {
-  /*
-   * The frame rate hints returned from ffmpeg for the video stream do not appear to take into
-   * account whether the content is interlaced. This affects the calculation to time offsets based
-   * on frames per second as most commercial detection programs use full frames, which need two
-   * interlaced fields to calculate a single frame so the actual frame rate is half.
-   *
-   * Adjust the frame rate using the detected frame rate or height to determine typical interlaced
-   * content (obtained from http://en.wikipedia.org/wiki/Frame_rate)
-   *
-   * Note that this is a HACK and we should be able to get the frame rate from the source sending
-   * back frame markers. However, this doesn't seem possible for MythTV.
-   */
-  float fFramesPerSecond;
-  if (iHeight <= 480 && int(fFrameRate * 100) == 5994) // 59.940 fps = NTSC or 60i content except for 1280x720/60
-  {
-    fFramesPerSecond = fFrameRate / 2; // ~29.97f - division used to retain accuracy of original.
-    CLog::Log(LOGDEBUG, "%s - Assuming NTSC or 60i interlaced content. Adjusted frames per second from %.3f (~59.940 fps) to %.3f",
-              __FUNCTION__, fFrameRate, fFramesPerSecond);
-  }
-  else if (int(fFrameRate * 100) == 4795) // 47.952 fps = 24p -> NTSC conversion
-  {
-    fFramesPerSecond = fFrameRate / 2; // ~23.976f - division used to retain accuracy of original.
-    CLog::Log(LOGDEBUG, "%s - Assuming 24p -> NTSC conversion interlaced content. Adjusted frames per second from %.3f (~47.952 fps) to %.3f",
-              __FUNCTION__, fFrameRate, fFramesPerSecond);
-  }
-  else if (iHeight == 576 && fFrameRate > 30.0) // PAL @ 50.0fps rather than PAL @ 25.0 fps. Can't use direct fps check of 50.0 as this is valid for 720p
-  {
-    fFramesPerSecond = fFrameRate / 2; // ~25.0f - division used to retain accuracy of original.
-    CLog::Log(LOGDEBUG, "%s - Assuming PAL interlaced content. Adjusted frames per second from %.3f (~50.00 fps) to %.3f",
-              __FUNCTION__, fFrameRate, fFramesPerSecond);
-  }
-  else if (iHeight == 1080 && fFrameRate > 30.0) // Don't know of any 1080p content being broadcast at higher than 30.0 fps so assume 1080i
-  {
-    fFramesPerSecond = fFrameRate / 2;
-    CLog::Log(LOGDEBUG, "%s - Assuming 1080i interlaced content. Adjusted frames per second from %.3f to %.3f",
-              __FUNCTION__, fFrameRate, fFramesPerSecond);
-  }
-  else // Assume everything else is not interlaced, e.g. 720p.
-    fFramesPerSecond = fFrameRate;
-
   bool bFound = false;
 
   /*
    * Only check for edit decision lists if the movie is on the local hard drive, or accessed over a
    * network share.
    */
-  if ((URIUtils::IsHD(strMovie)  || 
-       URIUtils::IsSmb(strMovie) || 
-       URIUtils::IsNfs(strMovie) || 
-       URIUtils::IsAfp(strMovie))         &&
-      !URIUtils::IsPVRRecording(strMovie) &&
-      !URIUtils::IsInternetStream(strMovie))
+  if (CUtil::IsHD(strMovie)
+  ||  CUtil::IsSmb(strMovie))
   {
-    CLog::Log(LOGDEBUG, "%s - Checking for edit decision lists (EDL) on local drive or remote share for: %s",
-              __FUNCTION__, strMovie.c_str());
+    CLog::Log(LOGDEBUG, "%s - checking for any edit decision lists (EDL) on local drive or remote share for: %s", __FUNCTION__,
+              strMovie.c_str());
 
     /*
      * Read any available file format until a valid EDL related file is found.
@@ -131,7 +84,7 @@ bool CEdl::ReadEditDecisionLists(const CStdString& strMovie, const float fFrameR
       bFound = ReadVideoReDo(strMovie);
 
     if (!bFound)
-      bFound = ReadEdl(strMovie, fFramesPerSecond);
+      bFound = ReadEdl(strMovie);
 
     if (!bFound)
       bFound = ReadComskip(strMovie, fFramesPerSecond);
@@ -142,27 +95,12 @@ bool CEdl::ReadEditDecisionLists(const CStdString& strMovie, const float fFrameR
   /*
    * Or if the movie points to MythTV and isn't live TV.
    */
-  else if (URIUtils::IsMythTV(strMovie)
-  &&      !URIUtils::IsLiveTV(strMovie))
+  else if (CUtil::IsMythTV(strMovie)
+  &&      !CUtil::IsLiveTV(strMovie))
   {
-    Clear(); // Don't clear in either ReadMyth* method as they are intended to be used together.
-    CLog::Log(LOGDEBUG, "%s - Checking for commercial breaks within MythTV for: %s", __FUNCTION__,
+    CLog::Log(LOGDEBUG, "%s - checking for any commercial breaks within MythTV for: %s", __FUNCTION__,
               strMovie.c_str());
-    bFound = ReadMythCommBreakList(strMovie, fFramesPerSecond);
-    CLog::Log(LOGDEBUG, "%s - Checking for cut list within MythTV for: %s", __FUNCTION__,
-              strMovie.c_str());
-    bFound |= ReadMythCutList(strMovie, fFramesPerSecond);
-  }
-
-  /*
-   * PVR Recordings
-   */
-  else if (URIUtils::IsPVRRecording(strMovie))
-  {
-    CLog::Log(LOGDEBUG, "%s - Checking for edit decision list (EDL) for PVR recording: %s",
-      __FUNCTION__, strMovie.c_str());
-
-    bFound = ReadPvr(strMovie);
+    bFound = ReadMythCommBreaks(strMovie, fFramesPerSecond);
   }
 
   if (bFound)
@@ -173,11 +111,12 @@ bool CEdl::ReadEditDecisionLists(const CStdString& strMovie, const float fFrameR
   return bFound;
 }
 
-bool CEdl::ReadEdl(const CStdString& strMovie, const float fFramesPerSecond)
+bool CEdl::ReadEdl(const CStdString& strMovie)
 {
   Clear();
 
-  CStdString edlFilename(URIUtils::ReplaceExtension(strMovie, ".edl"));
+  CStdString edlFilename;
+  CUtil::ReplaceExtension(strMovie, ".edl", edlFilename);
   if (!CFile::Exists(edlFilename))
     return false;
 
@@ -188,152 +127,61 @@ bool CEdl::ReadEdl(const CStdString& strMovie, const float fFramesPerSecond)
     return false;
   }
 
-  bool bError = false;
+  bool bValid = true;
+  char szBuffer[1024];
   int iLine = 0;
-  CStdString strBuffer;
-  while (edlFile.ReadString(strBuffer.GetBuffer(1024), 1024))
+  while (bValid && edlFile.ReadString(szBuffer, 1023))
   {
-    strBuffer.ReleaseBuffer();
-
-    // Log any errors from previous run in the loop
-    if (bError)
-      CLog::Log(LOGWARNING, "%s - Error on line %i in EDL file: %s", __FUNCTION__, iLine, edlFilename.c_str());
-
-    bError = false;
-
     iLine++;
 
-    char buffer1[513];
-    char buffer2[513];
+    double dStart, dEnd;
     int iAction;
-    int iFieldsRead = sscanf(strBuffer, "%512s %512s %i", buffer1,
-                             buffer2, &iAction);
-    if (iFieldsRead != 2 && iFieldsRead != 3) // Make sure we read the right number of fields
+    if (sscanf(szBuffer, "%lf %lf %i", &dStart, &dEnd, &iAction) == 3)
     {
-      bError = true;
-      continue;
-    }
+      if (dStart == dEnd) // Ignore zero length cuts in generated EDL files
+        continue;
 
-    vector<string> strFields(2);
-    strFields[0] = buffer1;
-    strFields[1] = buffer2;
+      Cut cut;
+      cut.start = (int)dStart * 1000; // ms to s
+      cut.end = (int)dEnd * 1000; // ms to s
 
-    if (iFieldsRead == 2) // If only 2 fields read, then assume it's a scene marker.
-    {
-      iAction = atoi(strFields[1].c_str());
-      strFields[1] = strFields[0];
-    }
-
-    /*
-     * For each of the first two fields read, parse based on whether it is a time string
-     * (HH:MM:SS.sss), frame marker (#12345), or normal seconds string (123.45).
-     */
-    int64_t iCutStartEnd[2];
-    for (int i = 0; i < 2; i++)
-    {
-      if (strFields[i].find(":") != std::string::npos) // HH:MM:SS.sss format
+      switch (iAction)
       {
-        vector<string> fieldParts = StringUtils::Split(strFields[i], ".");
-        if (fieldParts.size() == 1) // No ms
-        {
-          iCutStartEnd[i] = StringUtils::TimeStringToSeconds(fieldParts[0]) * (int64_t)1000; // seconds to ms
-        }
-        else if (fieldParts.size() == 2) // Has ms. Everything after the dot (.) is ms
-        {
-          /*
-           * Have to pad or truncate the ms portion to 3 characters before converting to ms.
-           */
-          if (fieldParts[1].length() == 1)
-          {
-            fieldParts[1] = fieldParts[1] + "00";
-          }
-          else if (fieldParts[1].length() == 2)
-          {
-            fieldParts[1] = fieldParts[1] + "0";
-          }
-          else if (fieldParts[1].length() > 3)
-          {
-            fieldParts[1] = fieldParts[1].substr(0, 3);
-          }
-          iCutStartEnd[i] = (int64_t)StringUtils::TimeStringToSeconds(fieldParts[0]) * 1000 + atoi(fieldParts[1].c_str()); // seconds to ms
-        }
-        else
-        {
-          bError = true;
-          continue;
-        }
-      }
-      else if (strFields[i][0] == '#') // #12345 format for frame number
-      {
-        iCutStartEnd[i] = (int64_t)(atol(strFields[i].substr(1).c_str()) / fFramesPerSecond * 1000); // frame number to ms
-      }
-      else // Plain old seconds in float format, e.g. 123.45
-      {
-        iCutStartEnd[i] = (int64_t)(atof(strFields[i].c_str()) * 1000); // seconds to ms
-      }
-    }
-
-    if (bError) // If there was an error in the for loop, ignore and continue with the next line
-      continue;
-
-    Cut cut;
-    cut.start = iCutStartEnd[0];
-    cut.end = iCutStartEnd[1];
-
-    switch (iAction)
-    {
-    case 0:
-      cut.action = CUT;
-      if (!AddCut(cut))
-      {
-        CLog::Log(LOGWARNING, "%s - Error adding cut from line %i in EDL file: %s", __FUNCTION__,
-                  iLine, edlFilename.c_str());
+      case 0:
+        cut.action = CUT;
+        bValid = AddCut(cut);
+        break;
+      case 1:
+        cut.action = MUTE;
+        bValid = AddCut(cut);
+        break;
+      case 2:
+        bValid = AddSceneMarker(cut.end);
+        break;
+      case 3:
+        cut.action = COMM_BREAK;
+        bValid = AddCut(cut);
+        break;
+      default:
+        bValid = false;
         continue;
       }
-      break;
-    case 1:
-      cut.action = MUTE;
-      if (!AddCut(cut))
-      {
-        CLog::Log(LOGWARNING, "%s - Error adding mute from line %i in EDL file: %s", __FUNCTION__,
-                  iLine, edlFilename.c_str());
-        continue;
-      }
-      break;
-    case 2:
-      if (!AddSceneMarker(cut.end))
-      {
-        CLog::Log(LOGWARNING, "%s - Error adding scene marker from line %i in EDL file: %s",
-                  __FUNCTION__, iLine, edlFilename.c_str());
-        continue;
-      }
-      break;
-    case 3:
-      cut.action = COMM_BREAK;
-      if (!AddCut(cut))
-      {
-        CLog::Log(LOGWARNING, "%s - Error adding commercial break from line %i in EDL file: %s",
-                  __FUNCTION__, iLine, edlFilename.c_str());
-        continue;
-      }
-      break;
-    default:
-      CLog::Log(LOGWARNING, "%s - Invalid action on line %i in EDL file: %s", __FUNCTION__, iLine,
-                edlFilename.c_str());
-      continue;
     }
+    else
+      bValid = false;
   }
-
-  strBuffer.ReleaseBuffer();
-
-  if (bError) // Log last line warning, if there was one, since while loop will have terminated.
-    CLog::Log(LOGWARNING, "%s - Error on line %i in EDL file: %s", __FUNCTION__, iLine, edlFilename.c_str());
-
   edlFile.Close();
 
-  if (HasCut() || HasSceneMarker())
+  if (!bValid)
   {
-    CLog::Log(LOGDEBUG, "%s - Read %"PRIuS" cuts and %"PRIuS" scene markers in EDL file: %s", __FUNCTION__,
+    CLog::Log(LOGERROR, "%s - Invalid EDL file: %s. Error in line %i. Clearing any valid cuts or scenes found.",
+              __FUNCTION__, edlFilename.c_str(), iLine);
+    Clear();
+    return false;
+  }
+  else if (HasCut() || HasSceneMarker())
+  {
+    CLog::Log(LOGDEBUG, "%s - Read %i cuts and %i scene markers in EDL file: %s", __FUNCTION__,
               m_vecCuts.size(), m_vecSceneMarkers.size(), edlFilename.c_str());
     return true;
   }
@@ -349,7 +197,8 @@ bool CEdl::ReadComskip(const CStdString& strMovie, const float fFramesPerSecond)
 {
   Clear();
 
-  CStdString comskipFilename(URIUtils::ReplaceExtension(strMovie, ".txt"));
+  CStdString comskipFilename;
+  CUtil::ReplaceExtension(strMovie, ".txt", comskipFilename);
   if (!CFile::Exists(comskipFilename))
     return false;
 
@@ -414,7 +263,7 @@ bool CEdl::ReadComskip(const CStdString& strMovie, const float fFramesPerSecond)
   }
   else if (HasCut())
   {
-    CLog::Log(LOGDEBUG, "%s - Read %"PRIuS" commercial breaks from Comskip file: %s", __FUNCTION__, m_vecCuts.size(),
+    CLog::Log(LOGDEBUG, "%s - Read %i commercial breaks from Comskip file: %s", __FUNCTION__, m_vecCuts.size(),
               comskipFilename.c_str());
     return true;
   }
@@ -434,7 +283,8 @@ bool CEdl::ReadVideoReDo(const CStdString& strMovie)
    */
 
   Clear();
-  CStdString videoReDoFilename(URIUtils::ReplaceExtension(strMovie, ".Vprj"));
+  CStdString videoReDoFilename;
+  CUtil::ReplaceExtension(strMovie, ".Vprj", videoReDoFilename);
   if (!CFile::Exists(videoReDoFilename))
     return false;
 
@@ -485,7 +335,7 @@ bool CEdl::ReadVideoReDo(const CStdString& strMovie)
       int iScene;
       double dSceneMarker;
       if (sscanf(szBuffer + strlen(VIDEOREDO_TAG_SCENE), " %i>%lf", &iScene, &dSceneMarker) == 2)
-        bValid = AddSceneMarker((int64_t)(dSceneMarker / 10000)); // Times need adjusting by 1/10,000 to get ms.
+        bValid = AddSceneMarker((int)dSceneMarker / 10000); // Times need adjusting by 1/10,000 to get ms.
       else
         bValid = false;
     }
@@ -504,7 +354,7 @@ bool CEdl::ReadVideoReDo(const CStdString& strMovie)
   }
   else if (HasCut() || HasSceneMarker())
   {
-    CLog::Log(LOGDEBUG, "%s - Read %"PRIuS" cuts and %"PRIuS" scene markers in VideoReDo file: %s", __FUNCTION__,
+    CLog::Log(LOGDEBUG, "%s - Read %i cuts and %i scene markers in VideoReDo file: %s", __FUNCTION__,
               m_vecCuts.size(), m_vecSceneMarkers.size(), videoReDoFilename.c_str());
     return true;
   }
@@ -520,11 +370,12 @@ bool CEdl::ReadBeyondTV(const CStdString& strMovie)
 {
   Clear();
 
-  CStdString beyondTVFilename(URIUtils::ReplaceExtension(strMovie, URIUtils::GetExtension(strMovie) + ".chapters.xml"));
+  CStdString beyondTVFilename;
+  CUtil::ReplaceExtension(strMovie, CUtil::GetExtension(strMovie) + ".chapters.xml", beyondTVFilename);
   if (!CFile::Exists(beyondTVFilename))
     return false;
 
-  CXBMCTinyXML xmlDoc;
+  TiXmlDocument xmlDoc;
   if (!xmlDoc.LoadFile(beyondTVFilename))
   {
     CLog::Log(LOGERROR, "%s - Could not load Beyond TV file: %s. %s", __FUNCTION__, beyondTVFilename.c_str(),
@@ -587,7 +438,7 @@ bool CEdl::ReadBeyondTV(const CStdString& strMovie)
   }
   else if (HasCut())
   {
-    CLog::Log(LOGDEBUG, "%s - Read %"PRIuS" commercial breaks from Beyond TV file: %s", __FUNCTION__, m_vecCuts.size(),
+    CLog::Log(LOGDEBUG, "%s - Read %i commercial breaks from Beyond TV file: %s", __FUNCTION__, m_vecCuts.size(),
               beyondTVFilename.c_str());
     return true;
   }
@@ -599,73 +450,7 @@ bool CEdl::ReadBeyondTV(const CStdString& strMovie)
   }
 }
 
-bool CEdl::ReadPvr(const CStdString &strMovie)
-{
-  if (!PVR::g_PVRManager.IsStarted())
-  {
-    CLog::Log(LOGERROR, "%s - PVR Manager not started, cannot read Edl for %s", __FUNCTION__, strMovie.c_str());
-    return false;
-  }
-
-  CFileItemPtr tag =  PVR::g_PVRRecordings->GetByPath(strMovie);
-  if (tag && tag->HasPVRRecordingInfoTag())
-  {
-    CLog::Log(LOGDEBUG, "%s - Reading Edl for recording: %s", __FUNCTION__, tag->GetPVRRecordingInfoTag()->m_strTitle.c_str());
-  }
-  else
-  {
-    CLog::Log(LOGERROR, "%s - Unable to find PVR recording: %s", __FUNCTION__, strMovie.c_str());
-    return false;
-  }
-
-  std::vector<PVR_EDL_ENTRY> edl = tag->GetPVRRecordingInfoTag()->GetEdl();
-  std::vector<PVR_EDL_ENTRY>::const_iterator it;
-  for (it = edl.begin(); it != edl.end(); ++it)
-  {
-    Cut cut;
-    cut.start = it->start;
-    cut.end = it->end;
-
-    switch (it->type)
-    {
-    case PVR_EDL_TYPE_CUT:
-      cut.action = CUT;
-      break;
-    case PVR_EDL_TYPE_MUTE:
-      cut.action = MUTE;
-      break;
-    case PVR_EDL_TYPE_SCENE:
-      if (!AddSceneMarker(cut.end))
-      {
-        CLog::Log(LOGWARNING, "%s - Error adding scene marker for pvr recording", __FUNCTION__);
-      }
-      continue;
-    case PVR_EDL_TYPE_COMBREAK:
-      cut.action = COMM_BREAK;
-      break;
-    default:
-      CLog::Log(LOGINFO, "%s - Ignoring entry of unknown type: %d", __FUNCTION__, it->type);
-      continue;
-    }
-
-    if (AddCut(cut))
-    {
-      CLog::Log(LOGDEBUG, "%s - Added break [%s - %s] found in PVRRecording for: %s.",
-        __FUNCTION__, MillisecondsToTimeString(cut.start).c_str(),
-        MillisecondsToTimeString(cut.end).c_str(), strMovie.c_str());
-    }
-    else
-    {
-      CLog::Log(LOGERROR, "%s - Invalid break [%s - %s] found in PVRRecording for: %s. Continuing anyway.",
-        __FUNCTION__, MillisecondsToTimeString(cut.start).c_str(),
-        MillisecondsToTimeString(cut.end).c_str(), strMovie.c_str());
-    }
-  }
-
- return !edl.empty();
-}
-
-bool CEdl::AddCut(Cut& cut)
+bool CEdl::AddCut(const Cut& cut)
 {
   if (cut.action != CUT && cut.action != MUTE && cut.action != COMM_BREAK)
   {
@@ -710,22 +495,6 @@ bool CEdl::AddCut(Cut& cut)
     }
   }
 
-  if (cut.action == COMM_BREAK)
-  {
-    /*
-     * Detection isn't perfect near the edges of commercial breaks so automatically wait for a bit at
-     * the start (autowait) and automatically rewind by a bit (autowind) at the end of the commercial
-     * break.
-     */
-    int autowait = g_advancedSettings.m_iEdlCommBreakAutowait * 1000; // seconds -> ms
-    int autowind = g_advancedSettings.m_iEdlCommBreakAutowind * 1000; // seconds -> ms
-
-    if (cut.start > 0) // Only autowait if not at the start.
-     cut.start += autowait;
-    if (cut.end > cut.start + autowind) // Only autowind if it won't go back past the start (should never happen).
-     cut.end -= autowind;
-  }
-
   /*
    * Insert cut in the list in the right position (ALL algorithms assume cuts are in ascending order)
    */
@@ -739,7 +508,7 @@ bool CEdl::AddCut(Cut& cut)
   else
   {
     vector<Cut>::iterator pCurrentCut;
-    for (pCurrentCut = m_vecCuts.begin(); pCurrentCut != m_vecCuts.end(); ++pCurrentCut)
+    for (pCurrentCut = m_vecCuts.begin(); pCurrentCut != m_vecCuts.end(); pCurrentCut++)
     {
       if (cut.start < pCurrentCut->start)
       {
@@ -788,7 +557,7 @@ bool CEdl::WriteMPlayerEdl()
   CStdString strBuffer;
   for (int i = 0; i < (int)m_vecCuts.size(); i++)
   {
-    /*
+    /* 
      * MPlayer doesn't understand the scene marker (2) or commercial break (3) identifiers that XBMC
      * supports in EDL files.
      *
@@ -796,7 +565,7 @@ bool CEdl::WriteMPlayerEdl()
      *
      * Write out mutes (1) directly. Treat commercial breaks as cuts (everything other than MUTES = 0).
      */
-    strBuffer += StringUtils::Format("%.3f\t%.3f\t%i\n", (float)(m_vecCuts[i].start / 1000),
+    strBuffer.AppendFormat("%.3f\t%.3f\t%i\n", (float)(m_vecCuts[i].start / 1000),
                                                (float)(m_vecCuts[i].end / 1000),
                                                m_vecCuts[i].action == MUTE ? 1 : 0);
   }
@@ -828,11 +597,6 @@ int64_t CEdl::RemoveCutTime(int64_t iSeek)
   if (!HasCut())
     return iSeek;
 
-  /*
-   * TODO: Consider an optimisation of using the (now unused) total cut time if the seek time
-   * requested is later than the end of the last recorded cut. For example, when calculating the
-   * total duration for display.
-   */
   int64_t iCutTime = 0;
   for (int i = 0; i < (int)m_vecCuts.size(); i++)
   {
@@ -869,6 +633,10 @@ bool CEdl::HasSceneMarker()
 
 CStdString CEdl::GetInfo()
 {
+  /*
+   * TODO: Update wiki (http://xbmc.org/wiki/?title=EDL_(commercial_skipping)_and_SceneMarker_support)
+   * if these different status strings are used.
+   */
   CStdString strInfo = "";
   if (HasCut())
   {
@@ -889,16 +657,16 @@ CStdString CEdl::GetInfo()
       }
     }
     if (cutCount > 0)
-      strInfo += StringUtils::Format("c%i", cutCount);
+      strInfo.AppendFormat("c%i", cutCount);
     if (muteCount > 0)
-      strInfo += StringUtils::Format("m%i", muteCount);
+      strInfo.AppendFormat("m%i", muteCount);
     if (commBreakCount > 0)
-      strInfo += StringUtils::Format("b%i", commBreakCount);
+      strInfo.AppendFormat("b%i", commBreakCount);
   }
   if (HasSceneMarker())
-    strInfo += StringUtils::Format("s%i", m_vecSceneMarkers.size());
+    strInfo.AppendFormat("s%i", m_vecSceneMarkers.size());
 
-  return strInfo.empty() ? "-" : strInfo;
+  return strInfo.IsEmpty() ? "-" : strInfo;
 }
 
 bool CEdl::InCut(const int64_t iSeek, Cut *pCut)
@@ -967,28 +735,31 @@ bool CEdl::GetNextSceneMarker(bool bPlus, const int64_t iClock, int64_t *iSceneM
 
 CStdString CEdl::MillisecondsToTimeString(const int64_t iMilliseconds)
 {
-  CStdString strTimeString = StringUtils::SecondsToTimeString((long)(iMilliseconds / 1000), TIME_FORMAT_HH_MM_SS); // milliseconds to seconds
-  strTimeString += StringUtils::Format(".%03i", iMilliseconds % 1000);
+  CStdString strTimeString = "";
+  StringUtils::SecondsToTimeString((long)(iMilliseconds / 1000), strTimeString, TIME_FORMAT_HH_MM_SS); // milliseconds to seconds
+  strTimeString.AppendFormat(".%03i", iMilliseconds % 1000);
   return strTimeString;
 }
 
-bool CEdl::ReadMythCommBreakList(const CStdString& strMovie, const float fFramesPerSecond)
+bool CEdl::ReadMythCommBreaks(const CStdString& strMovie, const float fFramesPerSecond)
 {
+  Clear();
+
   /*
    * Exists() sets up all the internal bits needed for GetCommBreakList().
    */
-  CMythFile mythFile;
+  CCMythFile mythFile;
   CURL url(strMovie);
   if (!mythFile.Exists(url))
     return false;
 
-  CLog::Log(LOGDEBUG, "%s - Reading commercial break list from MythTV for: %s", __FUNCTION__,
+  CLog::Log(LOGDEBUG, "%s - Reading commercial breaks from MythTV for: %s", __FUNCTION__,
             url.GetFileName().c_str());
 
   cmyth_commbreaklist_t commbreaklist;
   if (!mythFile.GetCommBreakList(commbreaklist))
   {
-    CLog::Log(LOGERROR, "%s - Error getting commercial break list from MythTV for: %s", __FUNCTION__,
+    CLog::Log(LOGERROR, "%s - Error getting commercial breaks from MythTV for: %s", __FUNCTION__,
               url.GetFileName().c_str());
     return false;
   }
@@ -999,18 +770,30 @@ bool CEdl::ReadMythCommBreakList(const CStdString& strMovie, const float fFrames
 
     Cut cut;
     cut.action = COMM_BREAK;
-    cut.start = (int64_t)(commbreak->start_mark / fFramesPerSecond * 1000);
-    cut.end = (int64_t)(commbreak->end_mark / fFramesPerSecond * 1000);
+    cut.start = (int)(commbreak->start_mark / fFramesPerSecond * 1000);
+    cut.end = (int)(commbreak->end_mark / fFramesPerSecond * 1000);
+
+    /*
+     * Detection isn't perfect near the edges so autowind by a small amount into each end of the
+     * detected commercial break.
+     *
+     * TODO: Advanced setting for the autowind amount. Perhaps one for fowards and one for backwards?
+     */
+    int autowind = 2 * 1000; // 2 seconds in ms
+    if (cut.start > 0) // Only autowind forwards if not at the start.
+      cut.start += autowind;
+    if (cut.end > cut.start + autowind) // Only autowind if it won't go back past the start (should never happen).
+      cut.end -= autowind;
 
     if (!AddCut(cut)) // Log and continue with errors while still testing.
-      CLog::Log(LOGERROR, "%s - Invalid commercial break [%s - %s] found in MythTV for: %s. Continuing anyway.",
+      CLog::Log(LOGERROR, "%s - Invalid commercial break [%s - %s] found in MythTV for: %s. autowind: %d. Continuing anyway.",
                 __FUNCTION__, MillisecondsToTimeString(cut.start).c_str(),
-                MillisecondsToTimeString(cut.end).c_str(), url.GetFileName().c_str());
+                MillisecondsToTimeString(cut.end).c_str(), url.GetFileName().c_str(), autowind);
   }
 
   if (HasCut())
   {
-    CLog::Log(LOGDEBUG, "%s - Added %"PRIuS" commercial breaks from MythTV for: %s. Used detected frame rate of %.3f fps to calculate times from the frame markers.",
+    CLog::Log(LOGDEBUG, "%s - Added %i commercial breaks from MythTV for: %s. Used detected frame rate of %.3f fps to calculate times from the frame markers.",
               __FUNCTION__, m_vecCuts.size(), url.GetFileName().c_str(), fFramesPerSecond);
     return true;
   }
@@ -1022,59 +805,6 @@ bool CEdl::ReadMythCommBreakList(const CStdString& strMovie, const float fFrames
   }
 }
 
-bool CEdl::ReadMythCutList(const CStdString& strMovie, const float fFramesPerSecond)
-{
-  /*
-   * Exists() sets up all the internal bits needed for GetCutList().
-   */
-  CMythFile mythFile;
-  CURL url(strMovie);
-  if (!mythFile.Exists(url))
-    return false;
-
-  CLog::Log(LOGDEBUG, "%s - Reading cut list from MythTV for: %s", __FUNCTION__,
-            url.GetFileName().c_str());
-
-  cmyth_commbreaklist_t commbreaklist;
-  if (!mythFile.GetCutList(commbreaklist))
-  {
-    CLog::Log(LOGERROR, "%s - Error getting cut list from MythTV for: %s", __FUNCTION__,
-              url.GetFileName().c_str());
-    return false;
-  }
-
-  bool found = false;
-  for (int i = 0; i < (int)commbreaklist->commbreak_count; i++)
-  {
-    cmyth_commbreak_t commbreak = commbreaklist->commbreak_list[i];
-
-    Cut cut;
-    cut.action = CUT;
-    cut.start = (int64_t)(commbreak->start_mark / fFramesPerSecond * 1000);
-    cut.end = (int64_t)(commbreak->end_mark / fFramesPerSecond * 1000);
-
-    if (!AddCut(cut)) // Log and continue with errors while still testing.
-      CLog::Log(LOGERROR, "%s - Invalid cut [%s - %s] found in MythTV for: %s. Continuing anyway.",
-                __FUNCTION__, MillisecondsToTimeString(cut.start).c_str(),
-                MillisecondsToTimeString(cut.end).c_str(), url.GetFileName().c_str());
-    else
-      found = true;
-  }
-
-  if (found)
-  {
-    CLog::Log(LOGDEBUG, "%s - Added %"PRIuS" cuts from MythTV for: %s. Used detected frame rate of %.3f fps to calculate times from the frame markers.",
-              __FUNCTION__, m_vecCuts.size(), url.GetFileName().c_str(), fFramesPerSecond);
-    return true;
-  }
-  else
-  {
-    CLog::Log(LOGDEBUG, "%s - No cut list found in MythTV for: %s", __FUNCTION__,
-              url.GetFileName().c_str());
-    return false;
-  }
-}
-
 void CEdl::MergeShortCommBreaks()
 {
   /*
