@@ -1,8 +1,8 @@
 #pragma once
 
 /*
- *      Copyright (C) 2005-2013 Team XBMC
- *      http://xbmc.org
+ *      Copyright (C) 2005-2008 Team XBMC
+ *      http://www.xbmc.org
  *
  *  This Program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,20 +15,21 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with XBMC; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
+ *  along with XBMC; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  http://www.gnu.org/copyleft/gpl.html
  *
  */
 
 #include "DllVorbisfile.h"
-#include "filesystem/File.h"
+#include "FileSystem/File.h"
 
 class COggCallback
 {
 public:
   COggCallback(XFILE::CFile& file);
-
-  static ov_callbacks Get(const CStdString& strFile);
+  
+  ov_callbacks Get(const CStdString& strFile);
 
   static size_t ReadCallback(void *ptr, size_t size, size_t nmemb, void *datasource);
   static int    SeekCallback(void *datasource, ogg_int64_t offset, int whence);
